
#line 3 "lex.yy.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 6
#define YY_FLEX_SUBMINOR_VERSION 4
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

#ifdef yyget_lval
#define yyget_lval_ALREADY_DEFINED
#else
#define yyget_lval yyget_lval
#endif

#ifdef yyset_lval
#define yyset_lval_ALREADY_DEFINED
#else
#define yyset_lval yyset_lval
#endif

#ifdef yyget_lloc
#define yyget_lloc_ALREADY_DEFINED
#else
#define yyget_lloc yyget_lloc
#endif

#ifdef yyset_lloc
#define yyset_lloc_ALREADY_DEFINED
#else
#define yyset_lloc yyset_lloc
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#ifndef SIZE_MAX
#define SIZE_MAX               (~(size_t)0)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

/* begin standard C++ headers. */

/* TODO: this is always defined, so inline it */
#define yyconst const

#if defined(__GNUC__) && __GNUC__ >= 3
#define yynoreturn __attribute__((__noreturn__))
#else
#define yynoreturn
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an
 *   integer in range [0..255] for use as an array index.
 */
#define YY_SC_TO_UI(c) ((YY_CHAR) (c))

/* An opaque pointer. */
#ifndef YY_TYPEDEF_YY_SCANNER_T
#define YY_TYPEDEF_YY_SCANNER_T
typedef void* yyscan_t;
#endif

/* For convenience, these vars (plus the bison vars far below)
   are macros in the reentrant scanner. */
#define yyin yyg->yyin_r
#define yyout yyg->yyout_r
#define yyextra yyg->yyextra_r
#define yyleng yyg->yyleng_r
#define yytext yyg->yytext_r
#define yylineno (YY_CURRENT_BUFFER_LVALUE->yy_bs_lineno)
#define yycolumn (YY_CURRENT_BUFFER_LVALUE->yy_bs_column)
#define yy_flex_debug yyg->yy_flex_debug_r

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN yyg->yy_start = 1 + 2 *
/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START ((yyg->yy_start - 1) / 2)
#define YYSTATE YY_START
/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)
/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE yyrestart( yyin , yyscanner )
#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k.
 * Moreover, YY_BUF_SIZE is 2*YY_READ_BUF_SIZE in the general case.
 * Ditto for the __ia64__ case accordingly.
 */
#define YY_BUF_SIZE 32768
#else
#define YY_BUF_SIZE 16384
#endif /* __ia64__ */
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2
    
    /* Note: We specifically omit the test for yy_rule_can_match_eol because it requires
     *       access to the local variable yy_act. Since yyless() is a macro, it would break
     *       existing scanners that call yyless() from OUTSIDE yylex.
     *       One obvious solution it to make yy_act a global. I tried that, and saw
     *       a 5% performance hit in a non-yylineno scanner, because yy_act is
     *       normally declared as a register variable-- so it is not worth it.
     */
    #define  YY_LESS_LINENO(n) \
            do { \
                int yyl;\
                for ( yyl = n; yyl < yyleng; ++yyl )\
                    if ( yytext[yyl] == '\n' )\
                        --yylineno;\
            }while(0)
    #define YY_LINENO_REWIND_TO(dst) \
            do {\
                const char *p;\
                for ( p = yy_cp-1; p >= (dst); --p)\
                    if ( *p == '\n' )\
                        --yylineno;\
            }while(0)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = yyg->yy_hold_char; \
		YY_RESTORE_YY_MORE_OFFSET \
		yyg->yy_c_buf_p = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )
#define unput(c) yyunput( c, yyg->yytext_ptr , yyscanner )

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	int yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */

	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( yyg->yy_buffer_stack \
                          ? yyg->yy_buffer_stack[yyg->yy_buffer_stack_top] \
                          : NULL)
/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE yyg->yy_buffer_stack[yyg->yy_buffer_stack_top]

void yyrestart ( FILE *input_file , yyscan_t yyscanner );
void yy_switch_to_buffer ( YY_BUFFER_STATE new_buffer , yyscan_t yyscanner );
YY_BUFFER_STATE yy_create_buffer ( FILE *file, int size , yyscan_t yyscanner );
void yy_delete_buffer ( YY_BUFFER_STATE b , yyscan_t yyscanner );
void yy_flush_buffer ( YY_BUFFER_STATE b , yyscan_t yyscanner );
void yypush_buffer_state ( YY_BUFFER_STATE new_buffer , yyscan_t yyscanner );
void yypop_buffer_state ( yyscan_t yyscanner );

static void yyensure_buffer_stack ( yyscan_t yyscanner );
static void yy_load_buffer_state ( yyscan_t yyscanner );
static void yy_init_buffer ( YY_BUFFER_STATE b, FILE *file , yyscan_t yyscanner );
#define YY_FLUSH_BUFFER yy_flush_buffer( YY_CURRENT_BUFFER , yyscanner)

YY_BUFFER_STATE yy_scan_buffer ( char *base, yy_size_t size , yyscan_t yyscanner );
YY_BUFFER_STATE yy_scan_string ( const char *yy_str , yyscan_t yyscanner );
YY_BUFFER_STATE yy_scan_bytes ( const char *bytes, int len , yyscan_t yyscanner );

void *yyalloc ( yy_size_t , yyscan_t yyscanner );
void *yyrealloc ( void *, yy_size_t , yyscan_t yyscanner );
void yyfree ( void * , yyscan_t yyscanner );

#define yy_new_buffer yy_create_buffer
#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        yyensure_buffer_stack (yyscanner); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE , yyscanner); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}
#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        yyensure_buffer_stack (yyscanner); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE , yyscanner); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}
#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */
typedef flex_uint8_t YY_CHAR;

typedef int yy_state_type;

#define yytext_ptr yytext_r

static yy_state_type yy_get_previous_state ( yyscan_t yyscanner );
static yy_state_type yy_try_NUL_trans ( yy_state_type current_state  , yyscan_t yyscanner);
static int yy_get_next_buffer ( yyscan_t yyscanner );
static void yynoreturn yy_fatal_error ( const char* msg , yyscan_t yyscanner );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	yyg->yytext_ptr = yy_bp; \
	yyleng = (int) (yy_cp - yy_bp); \
	yyg->yy_hold_char = *yy_cp; \
	*yy_cp = '\0'; \
	yyg->yy_c_buf_p = yy_cp;
#define YY_NUM_RULES 138
#define YY_END_OF_BUFFER 139
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static const flex_int16_t yy_accept[641] =
    {   0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,  105,  105,    0,    0,    0,    0,    0,    0,
      107,  107,  139,  137,  137,  134,  135,  137,   52,  137,
      136,  130,  137,  137,  137,  136,  137,   96,  137,  100,
      137,  132,   45,  136,  136,  136,   65,   33,  137,  136,
      136,  136,  137,  137,  137,  137,  137,  128,  134,  135,
      137,  116,  130,  137,  137,  136,  137,  136,  136,   96,
      137,  136,  136,  136,   64,  137,  135,  128,  135,    5,
        4,    5,    5,    5,    5,    5,    5,    5,    5,    5,

        8,  138,    8,    8,    8,    8,    8,    8,    8,   41,
       41,   40,  138,   39,   44,   44,   42,   44,   44,   44,
       44,   44,   44,   44,   44,   50,   46,   50,   47,   50,
       50,   50,   50,   50,   50,   50,   63,   61,   62,   63,
       60,   63,   58,   59,   63,   63,   63,   63,   63,   63,
       63,   86,   76,   76,   72,   86,   70,   84,   86,   86,
       75,   71,   86,   79,   74,   73,   85,   78,   77,   69,
       66,   67,   86,   86,   86,   86,   86,   86,   86,  104,
      104,  105,  103,  102,  104,  104,  104,  104,  104,  104,
      104,  104,  118,  111,  109,  111,  111,  111,  111,  111,

      111,  111,  111,  106,  106,  107,  106,  106,  106,  106,
      106,  106,  106,  106,    0,    0,    0,    0,    0,    0,
       33,    0,    0,    0,    0,  135,   95,   51,    0,  136,
      129,    0,   27,    1,    6,    0,    0,    0,    0,   91,
       19,   23,   20,   21,   30,   15,   26,   16,   22,   25,
       17,   24,   18,   99,   97,    0,   93,  131,    0,  136,
      136,  136,   33,  133,  136,  137,  136,  136,    0,    0,
        0,    0,    0,  128,    0,    0,  116,    0,    0,    0,
        0,    0,    0,    0,    0,    0,   64,    0,    0,    0,
        0,  128,   95,  115,    0,  121,    0,  136,  136,  127,

      136,  136,    0,   91,   93,    0,  135,  128,    0,    0,
      128,    4,    3,    2,    5,    0,    0,    0,    0,    0,
        0,    7,    8,    0,    0,    0,    0,    0,    0,   41,
       41,   40,    0,   39,    0,    0,    0,   44,    0,    0,
        0,    0,    0,    0,   48,   49,   50,    0,    0,    0,
        0,    0,    0,   62,    0,   60,   55,   57,   56,   53,
       54,   63,    0,    0,    0,    0,    0,    0,   76,   76,
       75,    0,   74,   73,   67,    0,   81,   83,    0,    0,
       80,   75,    9,   10,    0,   79,   74,   73,   85,   85,
       85,   68,   86,    0,    0,    0,    0,    0,    0,  105,

      103,  102,  101,  104,    0,    0,    0,    0,    0,    0,
      117,    0,  111,    0,    0,    0,    0,    0,    0,  107,
        0,  108,  106,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,   12,    0,   34,   34,    0,    0,    0,
        0,   30,    0,   31,   32,   99,    0,   92,   94,   38,
      136,  136,  136,    0,    0,    0,  128,    0,    0,    0,
        0,    0,    0,    0,    0,    0,   11,  128,    0,  121,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
      125,  127,  126,  125,    0,    0,    0,  128,  128,    0,
        0,    0,    0,    0,    0,   43,    0,    0,    0,    0,

        0,    0,    0,   57,    0,    0,    0,    0,    0,   79,
       85,   85,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,   34,   34,   34,   37,   35,    0,    0,    0,   30,
       32,    0,    0,  136,  136,  136,  128,    0,    0,    0,
        0,    0,  123,    0,    0,    0,    0,    0,    0,    0,
      125,  126,  125,   90,    0,    0,  128,   43,    0,    0,
        0,   57,    0,    0,    0,   85,   77,    0,  110,  120,
      119,    0,   29,   37,   35,   36,    0,    0,    0,   30,
       98,    0,  136,  136,   13,   13,  114,  113,  112,   89,

      122,  123,    0,    0,    0,    0,   90,   87,   88,    0,
       28,   57,    0,   82,   78,    0,   36,    0,    0,    0,
        0,   98,   98,    0,    0,  136,   89,  122,  124,   87,
       88,    0,    0,    0,    0,   14,    0,  124,    0,    0
    } ;

static const YY_CHAR yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    4,    5,    6,    7,    8,    9,    1,   10,   11,
       12,   13,   14,   15,   16,   17,   18,   19,   19,   19,
       19,   19,   19,   19,   19,   19,   19,   20,   21,   22,
       23,   24,   25,    1,   26,   26,   27,   27,   26,   28,
       26,   26,   27,   26,   26,   27,   27,   26,   26,   26,
       26,   26,   26,   29,   26,   27,   26,   27,   26,   26,
       30,   31,   32,   33,   34,   35,   36,   26,   27,   27,

       37,   38,   26,   39,   27,   26,   26,   40,   27,   26,
       26,   41,   26,   42,   43,   44,   45,   27,   46,   27,
       26,   26,   47,   48,   49,   50,    1,   51,   52,   52,
       52,   52,   52,   52,   52,   52,   52,   52,   52,   52,
       52,   52,   52,   53,   53,   53,   53,   54,   53,   53,
       53,   53,   53,   53,   53,   54,   54,   54,   54,   55,
       55,   55,   55,   55,   55,   55,   55,   55,   55,   55,
       55,   55,   55,   55,   55,   55,   55,   55,   55,   55,
       55,   55,   55,   55,   55,   55,   55,   55,   55,   55,
       55,   21,   21,   56,   56,   56,   56,   56,   56,   56,

       56,   56,   56,   56,   56,   56,   56,   56,   56,   56,
       56,   56,   56,   56,   56,   56,   56,   56,   56,   56,
       56,   56,   56,   57,   58,   58,   59,   59,   59,   59,
       59,   59,   59,   59,   59,   59,   60,   59,   59,   61,
       62,   62,   62,   63,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static const YY_CHAR yy_meta[64] =
    {   0,
        1,    2,    3,    4,    1,    1,    5,    6,    1,    7,
        7,    7,    1,    1,    7,    8,    9,    1,   10,    7,
        7,    1,    1,   11,   12,   13,   13,   13,   13,   14,
        6,   15,    1,    8,    1,   13,   13,   13,   13,   13,
       13,   13,   13,   13,   13,   13,   16,    1,   17,    1,
        7,    1,    1,    7,    7,   18,   18,   18,    2,    2,
        2,    2,    2
    } ;

static const flex_int16_t yy_base[684] =
    {   0,
        0,   62,   75,  109,  110,  117,  128,  135,  180,  241,
      128,  144,   68,  147,  303,  365,  426,  487,  550,    0,
      613,    0,  675,  737,    0,    0, 2404, 2403,  798,  859,
      921,  983, 2409, 2413,  210,  138,  213, 2377, 2398, 2354,
        0, 2387, 2385, 2381,   55, 2380,   95, 2356, 1040,  144,
     2355, 2339, 2337, 2327, 2325, 2322, 2413,   78, 2313,  114,
     2307,  167,  198,  127,  105,  211,   33, 1088,  306, 1135,
     2327,    0,  195,  253,  230,  251, 2350, 2336,  252, 2315,
     2317,   79,   80,   70, 2413,  270,  273,  278,  310, 2413,
     2343, 2326, 2330,  279, 2283,  295,  290,  118,  300,  144,

     2334, 2413,  320,   71,  332,  353,  323,  379,  159,    0,
      388, 2413,  391, 2413, 2413,  335, 2413, 2301,  357, 2279,
      362,  345,  262,  388,  243, 2413, 2298, 2293, 2413,  393,
     2270,  398,  411,  326,  415,  337, 2413, 2413, 2316, 2276,
        0,  428, 2413, 2413,  440, 2265,  445,  420,  348,  450,
      367, 2413,  680,  705, 2413, 2313, 2413, 2310, 2269, 2305,
      452, 2413,  263,  461,  504,  507,    0, 2274, 2267, 2413,
     2413, 2272,  461, 2229,  472,  477,  466,  481,  486, 2413,
      687,  709, 2413, 2413, 2256,  693, 2212,  704,  488,  663,
      709,  634,    0, 2413, 2413, 2230,  718, 2207,  723,  699,

      669,  728,  645, 2413,  763,  782,  800,  736, 2206,  754,
      762,  764,  769,  650,  828, 2246, 2242, 2244, 2240, 2219,
      307,  824, 2245, 2217, 2207,  863, 2413, 2413,    0,    0,
     2413, 2215, 2196, 2413, 2413, 2190, 2161, 2159, 2117, 2413,
     2413, 2413, 2413, 2413,  821, 2413, 2413, 2413, 2413, 2413,
     2413, 2413, 2413,  867, 2129, 2130, 2413, 2413, 2124, 2117,
     2113, 2110,  456, 2413,    0, 2413,  833,  838,  852,  877,
      882,  887,  892,    0, 2151, 2122,    0,  823,  946,  848,
      855, 2147, 2132,  932, 2112, 2103, 2413, 2119, 2110, 2064,
     2088,  701,    0, 2413,  871,  960, 1182, 2087,  948,  477,

     2086, 2085,  694,    0,    0,  954,  989, 1014, 2083, 2082,
     1017, 2080, 2413, 2413, 2413,  943,  959,  971,  976, 1045,
     1092, 2413, 2413, 1105, 1120, 1125, 1136, 1141, 1146,    0,
      833, 2413,  906, 2413,  969, 1883, 1882, 2413, 1151, 1156,
     1164, 1169, 1174, 1179, 2413, 2413, 2413, 1195, 1200, 1205,
     1210, 1215, 1220, 2413,    0,    0, 2413, 1899, 2413, 2413,
     2413, 2413, 1225, 1230, 1235, 1240, 1245, 1250, 1304, 1308,
      910, 1902,  997, 1004, 1883, 1906, 2413, 2413,    0, 1901,
     2413, 1055, 2413, 2413, 1891,  824, 1107, 1159,    0, 1868,
     1854, 2413, 2413, 1262, 1281, 1286, 1291, 1296, 1307, 1361,

     2413, 2413, 2413, 2413, 1317, 1323, 1328, 1333, 1338, 1343,
     2413, 1857, 2413, 1348, 1353, 1358, 1363, 1368, 1373, 1233,
     1427, 2413, 2413, 1381, 1389, 1394, 1399, 1404, 1409, 1875,
     1463, 1857, 1841, 2413,  239, 1150, 1034, 1837, 1811, 1783,
     1778, 1451,    0, 2413, 1467, 1470, 1782, 2413, 2413, 2413,
     1782, 1688, 1684, 1436, 1441, 1448, 1696,    0, 1692, 1691,
     1688,    0,    0, 1671, 1667, 1645, 2413,  807, 1604, 1061,
     1118, 1603, 1480, 1455, 1411, 1460, 1424, 1301, 1466,  845,
      690,  827,  950,  953, 1418, 1405, 1334,  896,    0, 1471,
     1476, 1481, 1486, 1491, 1496,  959, 1501, 1506, 1511, 1516,

     1521, 1526,  693, 1335,    0, 1531, 1536, 1541, 1045, 1307,
     1282, 1284, 1546, 1551, 1556, 1561, 1566, 1571, 1625, 1579,
     1587, 1592, 1597, 1602, 1607, 1481, 1057, 1306, 1164,    0,
     1203, 1013, 1316, 1661, 1101, 1662, 1165, 1125, 1131, 1650,
     1666, 1111, 1103, 1101, 1651, 1697, 1109,  135, 1669,  189,
     1035, 1047, 1165,  937, 1635, 1710, 1715, 1720, 1725, 1730,
     1478, 1671, 1672, 1689,  946,  906, 1030, 1784, 1770,    0,
      840,  828, 1772,    0,  825,  755,    0, 1788, 2413, 2413,
     2413, 1776, 2413, 1792, 1793, 1797,  712, 1783,    0, 1781,
     1802,  701,  696,  668, 1839,    0, 2413, 2413, 2413, 1805,

     1806, 1810,  676, 1778, 1783, 1788, 1811, 1814, 1818, 1806,
     2413,  500, 1840, 2413,    0, 1852, 1842,  419,  402,  338,
      312, 1859, 1868,    0,  309,  306, 1843, 1884, 1896, 1900,
     1901, 1857, 1870,  302,  267, 2413,  255, 1905,  229, 2413,
     1919, 1937, 1955, 1973, 1991, 2009, 2027, 2045, 2063, 2075,
     2093, 2111, 2129, 2140, 2148, 2165, 2183, 2194, 2207,  222,
     2218, 2234, 2251, 2269, 2287,  203, 2298,  200, 2304,  196,
     2314, 2322,  163, 2332,  116, 2342,  107, 2351,   81, 2357,
     2374, 2385, 2395
    } ;

static const flex_int16_t yy_def[684] =
    {   0,
      640,    1,    1,    2,    1,    2,    1,    2,  641,  641,
      642,  642,  643,  643,  644,  644,  645,  645,  640,   19,
      640,   21,  646,  646,  647,  647,  647,  647,  648,  648,
      649,  649,  640,  640,  640,  640,  640,  640,  640,  640,
      650,  640,  640,  640,  640,  650,  640,  640,  640,  640,
      640,  640,  640,  650,  650,  650,  640,  640,  640,  650,
      650,  650,  640,  640,  640,  640,  640,  640,  640,  640,
      640,  651,  640,  640,  640,  650,  640,  650,  650,  652,
      640,  650,  650,  650,  640,  640,  640,   68,   70,  640,
      640,  640,  640,  640,  640,  640,  640,  640,  640,  640,

      640,  640,  640,  640,  640,  640,  640,  640,  640,  653,
      653,  640,  640,  640,  640,  640,  640,  640,  640,  640,
      640,  640,  640,  640,  640,  640,  640,  640,  640,  640,
      640,  640,  640,  640,  640,  640,  640,  640,  640,  640,
      654,  655,  640,  640,  640,  640,  640,  640,  640,  640,
      640,  640,  640,  640,  640,  656,  640,  640,  640,  657,
      640,  640,  640,  640,  640,  640,  658,  658,  658,  640,
      640,  640,  640,  640,  640,  640,  640,  640,  640,  640,
      640,  640,  640,  640,  640,  640,  640,  640,  640,  640,
      640,  640,  659,  640,  640,  640,  640,  640,  640,  640,

      640,  640,  640,  640,  640,  640,  640,  640,  640,  640,
      640,  640,  640,  640,  640,  640,  640,  640,  640,  640,
      640,  640,  640,  640,  640,  640,  640,  640,  660,  650,
      640,  640,  640,  640,  640,  640,  640,  640,  640,  640,
      640,  640,  640,  640,  661,  640,  640,  640,  640,  640,
      640,  640,  640,  640,  640,  640,  640,  640,  640,  650,
      650,  650,  640,  640,  650,  640,  650,  650,  640,  640,
      640,  640,  640,   68,   70,  640,  651,  640,  640,  640,
      640,  640,  640,  640,  652,  640,  640,  640,  640,  640,
       70,   68,  662,  640,  640,  640,  663,  650,  650,  640,

      650,  650,  652,  664,  665,  640,  640,   68,   89,   89,
       68,  640,  640,  640,  640,  640,  640,  640,  640,  640,
      640,  640,  640,  640,  640,  640,  640,  640,  640,  653,
      653,  640,  640,  640,  640,  640,  640,  640,  640,  640,
      640,  640,  640,  640,  640,  640,  640,  640,  640,  640,
      640,  640,  640,  640,  666,  654,  640,  667,  640,  640,
      640,  640,  640,  640,  640,  640,  640,  640,  640,  640,
      640,  640,  640,  640,  640,  656,  640,  640,  668,  657,
      640,  640,  640,  640,  640,  640,  640,  640,  658,  658,
      658,  640,  640,  640,  640,  640,  640,  640,  640,  640,

      640,  640,  640,  640,  640,  640,  640,  640,  640,  640,
      640,  640,  640,  640,  640,  640,  640,  640,  640,  640,
      640,  640,  640,  640,  640,  640,  640,  640,  640,  640,
      640,  640,  640,  640,  669,  640,  640,  640,  640,  640,
      640,  661,  670,  640,  640,  640,  640,  640,  640,  640,
      650,  650,  650,  640,  640,  640,   68,  662,  640,  640,
      640,  664,  665,  640,  640,  640,  640,   68,  662,  640,
      640,  671,  640,  640,  640,  640,  640,  640,  640,  640,
      640,  640,  640,  640,  640,  664,  665,  311,  311,  640,
      640,  640,  640,  640,  640,  640,  640,  640,  640,  640,

      640,  640,  672,  667,  673,  640,  640,  640,  674,  640,
      658,  658,  640,  640,  640,  640,  640,  640,  640,  640,
      640,  640,  640,  640,  640,  640,  640,  640,  669,  675,
      640,  640,  640,  640,  640,  640,  640,  640,  640,  676,
      640,  640,  640,  650,  650,  640,   68,  640,  640,  640,
      640,  640,  640,  640,  640,  640,  640,  640,  640,  640,
      640,  640,  640,  640,  640,  640,  311,  640,  672,  677,
      640,  678,  674,  679,  640,  658,  658,  640,  640,  640,
      640,  680,  640,  640,  640,  640,  640,  640,  681,  676,
      640,  640,  650,  650,  546,  546,  640,  640,  640,  640,

      640,  640,  640,  640,  640,  640,  640,  640,  640,  682,
      640,  678,  683,  640,  658,  680,  640,  640,  640,  640,
      681,  640,  640,  595,  640,  650,  640,  640,  640,  640,
      640,  682,  683,  640,  640,  640,  640,  640,  640,    0,
      640,  640,  640,  640,  640,  640,  640,  640,  640,  640,
      640,  640,  640,  640,  640,  640,  640,  640,  640,  640,
      640,  640,  640,  640,  640,  640,  640,  640,  640,  640,
      640,  640,  640,  640,  640,  640,  640,  640,  640,  640,
      640,  640,  640
    } ;

static const flex_int16_t yy_nxt[2477] =
    {   0,
       34,   35,   36,   37,   38,   34,   34,   39,   40,   41,
       41,   41,   42,   43,   41,   44,   41,   45,   41,   46,
       41,   47,   34,   34,   34,   41,   41,   41,   41,   48,
       49,   50,   51,   52,   53,   41,   41,   54,   55,   41,
       41,   41,   41,   41,   41,   56,   57,   58,   34,   59,
       41,   34,   34,   41,   41,   60,   61,   62,   63,   64,
       65,   66,   67,   68,   69,   70,   71,  234,   72,  111,
      112,  113,  235,  322,   73,   74,   86,   75,   87,  263,
       76,  263,   34,  273,  273,   77,  301,   78,   79,   78,
       78,   80,   34,  613,   81,  301,  301,   78,   78,   82,

       83,   79,   78,   78,   78,   78,   78,   84,   85,   34,
       88,   86,   89,   87,  114,  262,   34,   34,   88,  610,
       89,   34,  260,  261,   34,  324,   34,   34,  582,   86,
      102,   87,  237,  238,   34,   34,   88,  597,   89,  222,
      239,  223,   34,   34,   34,   34,  102,  548,  111,  112,
      113,   34,   34,  224,  254,   34,   34,  271,  271,  271,
      225,  322,   34,   34,  265,  266,  266,  265,  265,   34,
      319,  319,  319,  255,   34,  572,  256,  270,  270,  270,
      270,   34,   91,  103,  104,  105,  105,  106,  107,  108,
      109,  599,   92,  114,  321,  321,  295,   93,  296,  103,

      104,  105,  105,  106,  107,  108,  109,  231,  540,  329,
      329,  215,  509,  215,  215,  503,  226,  268,  269,  269,
      268,  268,  550,  216,  297,  217,  216,  218,  217,  219,
      218,  295,  219,  296,  435,   94,   95,   96,   96,   97,
       98,   99,  100,   91,  220,  233,  589,  220,  269,  269,
      269,  269,  269,   92,  295,  530,  296,  221,   93,  297,
      221,  272,  272,  272,  272,  272,  232,  298,  302,  299,
      299,  306,  624,  306,  306,  383,  307,  299,  299,  308,
      384,  309,  297,  216,  639,  217,  216,  531,  217,  219,
      299,  299,  219,  344,  344,  640,   94,   95,   96,   96,

       97,   98,   99,  100,  116,  117,  116,  222,  263,  223,
      263,  310,  640,  311,  342,  342,  342,  221,  288,  589,
      221,  289,  322,  637,  640,  322,  624,  640,  225,  315,
      315,  315,  315,  315,  322,  636,  335,  118,  335,  290,
      318,  318,  318,  318,  640,  317,  317,  317,  317,  317,
      320,  320,  320,  320,  320,  322,  640,  635,  119,  120,
      121,  121,  122,  123,  124,  125,  116,  117,  116,  336,
      323,  323,  323,  323,  323,  327,  327,  327,  351,  351,
      351,  322,  325,  325,  325,  325,  325,  353,  353,  331,
      332,  333,  333,  332,  333,  341,  341,  341,  341,  118,

      366,  366,  366,  326,  326,  326,  326,  338,  338,  338,
      338,  338,  340,  340,  340,  340,  340,  368,  368,  634,
      119,  120,  121,  121,  122,  123,  124,  125,  127,  328,
      328,  328,  328,  328,  334,  357,  589,  334,  343,  343,
      343,  343,  343,  347,  347,  347,  347,  347,  349,  349,
      349,  349,  349,  382,  382,  382,  128,  263,  359,  263,
      129,  350,  350,  350,  350,  352,  352,  352,  352,  352,
      365,  365,  365,  365,  360,  385,  361,  385,  482,  386,
      482,  130,  131,  132,  132,  133,  134,  135,  136,  127,
      362,  362,  362,  362,  362,  364,  364,  364,  364,  364,

      367,  367,  367,  367,  367,  387,  387,  387,  388,  388,
      388,  393,  393,  393,  393,  393,  505,  128,  397,  397,
      397,  129,  395,  395,  395,  395,  395,  396,  396,  396,
      396,  398,  398,  398,  398,  398,  399,  399,  407,  407,
      407,  407,  130,  131,  132,  132,  133,  134,  135,  136,
      137,  137,  138,  137,  137,  137,  137,  139,  140,  137,
      137,  137,  137,  137,  137,  137,  137,  137,  137,  137,
      137,  137,  137,  137,  137,  141,  141,  141,  141,  137,
      142,  137,  137,  137,  137,  141,  141,  141,  141,  141,
      141,  141,  141,  141,  141,  141,  143,  137,  144,  137,

      137,  137,  137,  137,  137,  145,  146,  147,  147,  148,
      149,  150,  151,  152,  153,  154,  153,  155,  156,  157,
      158,  159,  160,  152,  152,  152,  152,  161,  152,  162,
      163,  164,  165,  152,  152,  166,  152,  152,  167,  167,
      168,  169,  170,  152,  152,  152,  152,  152,  167,  167,
      168,  167,  167,  167,  167,  167,  169,  167,  167,  171,
      152,  172,  152,  152,  152,  152,  152,  152,  173,  174,
      175,  175,  176,  177,  178,  179,  181,  182,  181,  629,
      183,  369,  370,  369,  410,  410,  184,  626,  400,  400,
      400,  561,  401,  561,  371,  419,  419,  372,  402,  373,

      429,  429,  374,  467,  468,  185,  370,  370,  370,  570,
      400,  400,  400,  625,  401,  408,  408,  408,  624,  371,
      402,  417,  417,  417,  373,  485,  640,  374,  375,  618,
      186,  187,  188,  188,  189,  190,  191,  192,  181,  182,
      181,  571,  183,  404,  404,  404,  404,  404,  184,  416,
      416,  416,  416,  375,  406,  406,  406,  406,  406,  409,
      409,  409,  409,  409,  420,  420,  420,  185,  413,  413,
      413,  413,  413,  415,  415,  415,  415,  415,  418,  418,
      418,  418,  418,  420,  420,  420,  423,  423,  423,  423,
      423,  615,  186,  187,  188,  188,  189,  190,  191,  192,

      195,  421,  421,  421,  425,  425,  425,  425,  425,  467,
      468,  422,  426,  426,  426,  426,  427,  427,  427,  428,
      428,  428,  428,  428,  295,  222,  296,  223,  482,  215,
      482,  215,  196,  614,  331,  332,  333,  443,  385,  224,
      385,  216,  386,  217,  505,  218,  225,  219,  611,  295,
      444,  296,  297,  197,  198,  199,  199,  200,  201,  202,
      203,  195,  220,  430,  215,  434,  226,  445,  446,  446,
      446,  459,  295,  281,  295,  221,  216,  297,  217,  334,
      218,  281,  219,  265,  266,  266,  265,  265,  265,  266,
      266,  265,  265,  196,  281,  560,  560,  220,  640,  567,

      297,  447,  266,  266,  266,  266,  266,  333,  332,  333,
      221,  382,  382,  382,  197,  198,  199,  199,  200,  201,
      202,  203,  205,  206,  205,  609,  207,  266,  266,  266,
      266,  266,  454,  454,  454,  454,  454,  455,  455,  455,
      455,  455,  456,  456,  456,  456,  456,  295,  461,  296,
      281,  562,  334,  562,  563,  306,  563,  306,  281,  232,
      568,  470,  568,  470,  298,  608,  299,  216,  603,  217,
      335,  281,  335,  219,  299,  297,  208,  209,  210,  210,
      211,  212,  213,  214,  205,  206,  205,  299,  207,  297,
      306,  434,  307,  315,  315,  315,  315,  315,  387,  387,

      387,  221,  216,  336,  217,  388,  388,  388,  219,  315,
      315,  315,  315,  315,  532,  308,  532,  309,  308,  467,
      489,  315,  315,  315,  315,  315,  490,  490,  490,  490,
      490,  640,  640,  567,  640,  532,  221,  532,  208,  209,
      210,  210,  211,  212,  213,  214,  241,  242,  640,  534,
      601,  640,  243,  535,  600,  244,  382,  382,  382,  580,
      640,  574,  470,  640,  470,  245,  245,  245,  245,  246,
      247,  248,  527,  249,  250,  245,  245,  245,  245,  245,
      245,  245,  245,  245,  245,  245,  251,  252,  253,  274,
      297,  275,  276,  575,  277,  491,  491,  491,  491,  491,

      278,  279,  584,  280,  584,  218,  281,  219,  387,  387,
      387,  282,  547,  283,  284,  283,  283,  285,  592,  471,
      286,  471,  220,  283,  283,  283,  283,  284,  283,  283,
      283,  283,  283,  283,  287,  221,  291,  591,  292,  276,
      444,  277,  492,  492,  492,  492,  492,  589,  216,  473,
      217,  532,  218,  532,  219,  323,  323,  323,  323,  323,
      388,  388,  388,  533,  285,  588,  602,  286,  602,  220,
      323,  323,  323,  323,  323,  323,  323,  323,  323,  323,
      530,  287,  221,  471,  587,  471,  493,  493,  493,  493,
      493,  494,  494,  494,  494,  494,  495,  495,  495,  495,

      495,  338,  338,  338,  338,  338,  338,  338,  338,  338,
      338,  583,  531,  473,  338,  338,  338,  338,  338,  497,
      497,  497,  497,  497,  498,  498,  498,  498,  498,  499,
      499,  499,  499,  499,  420,  420,  420,  474,  475,  476,
      476,  477,  478,  479,  480,  347,  347,  347,  347,  347,
      347,  347,  347,  347,  347,  347,  347,  347,  347,  347,
      500,  500,  500,  500,  500,  501,  501,  501,  501,  501,
      502,  502,  502,  502,  502,  362,  362,  362,  362,  362,
      362,  362,  362,  362,  362,  362,  362,  362,  362,  362,
      506,  506,  506,  506,  506,  507,  507,  507,  507,  507,

      508,  508,  508,  508,  508,  369,  370,  369,  581,  370,
      370,  370,  393,  393,  393,  393,  393,  532,  371,  532,
      577,  372,  371,  373,  576,  510,  374,  373,  528,  533,
      374,  393,  393,  393,  393,  393,  393,  393,  393,  393,
      393,  513,  513,  513,  513,  513,  514,  514,  514,  514,
      514,  505,  375,  558,  558,  558,  375,  515,  515,  515,
      515,  515,  400,  400,  400,  566,  401,  404,  404,  404,
      404,  404,  402,  404,  404,  404,  404,  404,  404,  404,
      404,  404,  404,  516,  516,  516,  516,  516,  517,  517,
      517,  517,  517,  518,  518,  518,  518,  518,  413,  413,

      413,  413,  413,  413,  413,  413,  413,  413,  413,  413,
      413,  413,  413,  520,  520,  520,  520,  520,  521,  521,
      521,  521,  521,  522,  522,  522,  522,  522,  421,  421,
      421,  423,  423,  423,  423,  423,  565,  564,  422,  423,
      423,  423,  423,  423,  423,  423,  423,  423,  423,  523,
      523,  523,  523,  523,  524,  524,  524,  524,  524,  525,
      525,  525,  525,  525,  222,  555,  526,  443,  541,  541,
      541,  446,  446,  446,  557,  557,  557,  557,  224,  561,
      444,  561,  222,  553,  526,  225,  266,  266,  266,  266,
      266,  266,  266,  266,  266,  266,  224,  445,  266,  266,

      266,  266,  266,  225,  447,  554,  554,  554,  554,  554,
      556,  556,  556,  556,  556,  542,  559,  559,  559,  559,
      559,  315,  315,  315,  315,  315,  315,  315,  315,  315,
      315,  315,  315,  315,  315,  315,  323,  323,  323,  323,
      323,  323,  323,  323,  323,  323,  323,  323,  323,  323,
      323,  338,  338,  338,  338,  338,  338,  338,  338,  338,
      338,  338,  338,  338,  338,  338,  347,  347,  347,  347,
      347,  347,  347,  347,  347,  347,  347,  347,  347,  347,
      347,  362,  362,  362,  362,  362,  362,  362,  362,  362,
      362,  362,  362,  362,  362,  362,  393,  393,  393,  393,

      393,  393,  393,  393,  393,  393,  393,  393,  393,  393,
      393,  404,  404,  404,  404,  404,  404,  404,  404,  404,
      404,  404,  404,  404,  404,  404,  578,  578,  578,  413,
      413,  413,  413,  413,  552,  551,  579,  413,  413,  413,
      413,  413,  413,  413,  413,  413,  413,  423,  423,  423,
      423,  423,  423,  423,  423,  423,  423,  423,  423,  423,
      423,  423,  532,  585,  532,  585,  443,  541,  541,  541,
      593,  598,  562,  563,  562,  563,  534,  536,  550,  444,
      535,  586,  549,  548,  549,  554,  554,  554,  554,  554,
      607,  484,  607,  594,  483,  481,  445,  595,  595,  547,

      546,  595,  595,  595,  595,  595,  596,  596,  596,  595,
      595,  596,  595,  596,  595,  596,  596,  596,  595,  595,
      595,  595,  596,  596,  596,  596,  595,  595,  545,  595,
      595,  595,  596,  596,  596,  596,  596,  596,  596,  596,
      596,  596,  596,  595,  595,  595,  595,  596,  595,  595,
      596,  596,  596,  596,  596,  595,  595,  595,  595,  595,
      554,  554,  554,  554,  554,  554,  554,  554,  554,  554,
      604,  604,  604,  604,  604,  605,  605,  605,  605,  605,
      606,  606,  606,  606,  606,  568,  570,  568,  574,  578,
      578,  578,  530,  584,  585,  584,  585,  443,  617,  579,

      617,  544,  619,  622,  622,  622,  627,  628,  627,  628,
      444,  602,  607,  602,  607,  630,  543,  630,  571,  631,
      575,  631,  570,  539,  531,  620,  538,  445,  554,  554,
      554,  554,  554,  554,  554,  554,  554,  554,  554,  554,
      554,  554,  554,  617,  627,  617,  627,  623,  595,  595,
      595,  537,  536,  595,  571,  595,  574,  595,  595,  595,
      622,  622,  622,  528,  595,  595,  595,  595,  530,  622,
      622,  622,  527,  570,  595,  595,  595,  595,  595,  595,
      595,  595,  595,  595,  595,  628,  574,  628,  575,  595,
      437,  519,  595,  595,  595,  595,  595,  638,  512,  638,

      531,  630,  631,  630,  631,  571,  638,  511,  638,  510,
      381,  377,  392,  623,  383,  505,  496,  337,  575,   90,
       90,   90,   90,   90,   90,   90,   90,   90,   90,   90,
       90,   90,   90,   90,   90,   90,   90,  101,  101,  101,
      101,  101,  101,  101,  101,  101,  101,  101,  101,  101,
      101,  101,  101,  101,  101,  110,  110,  110,  110,  110,
      110,  110,  110,  110,  110,  110,  110,  110,  110,  110,
      110,  110,  110,  115,  115,  115,  115,  115,  115,  115,
      115,  115,  115,  115,  115,  115,  115,  115,  115,  115,
      115,  126,  126,  126,  126,  126,  126,  126,  126,  126,

      126,  126,  126,  126,  126,  126,  126,  126,  126,  180,
      180,  180,  180,  180,  180,  180,  180,  180,  180,  180,
      180,  180,  180,  180,  180,  180,  180,  102,  102,  102,
      102,  102,  102,  102,  102,  102,  102,  102,  102,  102,
      102,  102,  102,  102,  102,  194,  194,  194,  194,  194,
      194,  194,  194,  194,  194,  194,  194,  194,  194,  194,
      194,  194,  194,  204,  204,  204,  204,  204,  204,  204,
      204,  204,  204,  204,  204,  204,  204,  204,  204,  204,
      204,  230,  312,  230,  230,  310,  488,  230,  484,  483,
      481,  291,  230,  294,  294,  294,  294,  466,  294,  294,

      294,  294,  294,  294,  294,  294,  294,  294,  294,  294,
      294,  303,  303,  303,  303,  303,  303,  303,  303,  303,
      303,  303,  303,  303,  303,  465,  303,  303,  303,  330,
      330,  464,  463,  330,  330,  330,  330,  330,  330,  330,
      330,  330,  330,  330,  462,  330,  330,  356,  460,  356,
      300,  458,  356,  358,  457,  453,  452,  451,  450,  449,
      358,  448,  441,  358,  358,  376,  376,  376,  376,  376,
      376,  376,  376,  376,  376,  376,  376,  376,  376,  376,
      376,  376,  376,  380,  380,  380,  380,  380,  380,  380,
      380,  380,  380,  380,  380,  380,  380,  380,  380,  380,

      380,  389,  440,  389,  439,  438,  389,  411,  411,  411,
      411,  437,  411,  411,  411,  411,  411,  411,  411,  411,
      411,  411,  411,  411,  411,  442,  442,  442,  436,  433,
      442,  442,  432,  442,  469,  469,  469,  469,  469,  469,
      469,  469,  469,  469,  469,  469,  469,  469,  431,  469,
      469,  469,  472,  259,  472,  236,  234,  430,  472,  232,
      424,  414,  472,  472,  412,  472,  405,  403,  472,  486,
      486,  486,  486,  486,  486,  486,  486,  486,  486,  486,
      486,  486,  486,  394,  486,  486,  486,  487,  487,  487,
      487,  487,  487,  487,  487,  487,  487,  487,  487,  487,

      487,  392,  487,  487,  487,  504,  504,  504,  391,  390,
      504,  529,  529,  529,  381,  379,  529,  378,  377,  363,
      529,  472,  355,  354,  348,  472,  472,  346,  472,  569,
      569,  569,  345,  339,  569,  337,  322,  316,  569,  573,
      573,  573,  314,  313,  573,  312,  305,  304,  573,  590,
      590,  590,  301,  300,  590,  590,  293,  590,  612,  612,
      612,  267,  264,  612,  616,  616,  616,  262,  261,  616,
      260,  259,  258,  616,  621,  621,  621,  621,  621,  621,
      621,  621,  621,  621,  257,  621,  621,  621,  240,  621,
      621,  621,  632,  632,  632,  236,  233,  632,  232,  231,

      229,  632,  633,  633,  633,  228,  227,  633,  640,  193,
      193,  633,   33,  640,  640,  640,  640,  640,  640,  640,
      640,  640,  640,  640,  640,  640,  640,  640,  640,  640,
      640,  640,  640,  640,  640,  640,  640,  640,  640,  640,
      640,  640,  640,  640,  640,  640,  640,  640,  640,  640,
      640,  640,  640,  640,  640,  640,  640,  640,  640,  640,
      640,  640,  640,  640,  640,  640,  640,  640,  640,  640,
      640,  640,  640,  640,  640,  640
    } ;

static const flex_int16_t yy_chk[2477] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    2,    2,    2,    2,   45,    2,   13,
       13,   13,   45,  104,    2,    2,    3,    2,    3,   58,
        2,   58,    3,   67,   67,    2,   84,    2,    2,    2,
        2,    2,    3,  679,    2,   82,   83,    2,    2,    2,

        2,    2,    2,    2,    2,    2,    2,    2,    2,    3,
        4,    5,    4,    5,   13,   84,    4,    5,    6,  677,
        6,    3,   82,   83,    6,  104,    4,    5,  675,    7,
       11,    7,   47,   47,    6,    7,    8,  548,    8,   36,
       47,   36,    8,    4,    5,    7,   12,  548,   14,   14,
       14,    6,    8,   36,   50,    4,    5,   65,   65,   65,
       36,  109,    7,    6,   60,   60,   60,   60,   60,    8,
       98,   98,   98,   50,    7,  673,   50,   64,   64,   64,
       64,    8,    9,   11,   11,   11,   11,   11,   11,   11,
       11,  550,    9,   14,  100,  100,   73,    9,   73,   12,

       12,   12,   12,   12,   12,   12,   12,   73,  670,  109,
      109,   35,  668,   35,   37,  666,   37,   62,   62,   62,
       62,   62,  550,   35,   73,   35,   37,   35,   37,   35,
       37,   75,   37,   75,  660,    9,    9,    9,    9,    9,
        9,    9,    9,   10,   35,   75,  639,   37,   63,   63,
       63,   63,   63,   10,   74,  435,   74,   35,   10,   75,
       37,   66,   66,   66,   66,   66,   74,   76,   79,   76,
       79,   86,  637,   86,   87,  163,   87,   76,   79,   88,
      163,   88,   74,   86,  635,   86,   87,  435,   87,   86,
       76,   79,   87,  125,  125,   88,   10,   10,   10,   10,

       10,   10,   10,   10,   15,   15,   15,   69,  221,   69,
      221,   89,   88,   89,  123,  123,  123,   86,   69,  634,
       87,   69,  103,  626,   88,  107,  625,   89,   69,   94,
       94,   94,   94,   94,  105,  621,  116,   15,  116,   69,
       97,   97,   97,   97,   89,   96,   96,   96,   96,   96,
       99,   99,   99,   99,   99,  106,   89,  620,   15,   15,
       15,   15,   15,   15,   15,   15,   16,   16,   16,  116,
      103,  103,  103,  103,  103,  107,  107,  107,  134,  134,
      134,  108,  105,  105,  105,  105,  105,  136,  136,  111,
      111,  111,  113,  113,  113,  122,  122,  122,  122,   16,

      149,  149,  149,  106,  106,  106,  106,  119,  119,  119,
      119,  119,  121,  121,  121,  121,  121,  151,  151,  619,
       16,   16,   16,   16,   16,   16,   16,   16,   17,  108,
      108,  108,  108,  108,  111,  142,  618,  113,  124,  124,
      124,  124,  124,  130,  130,  130,  130,  130,  132,  132,
      132,  132,  132,  161,  161,  161,   17,  263,  142,  263,
       17,  133,  133,  133,  133,  135,  135,  135,  135,  135,
      148,  148,  148,  148,  142,  164,  142,  164,  300,  164,
      300,   17,   17,   17,   17,   17,   17,   17,   17,   18,
      145,  145,  145,  145,  145,  147,  147,  147,  147,  147,

      150,  150,  150,  150,  150,  165,  165,  165,  166,  166,
      166,  173,  173,  173,  173,  173,  612,   18,  177,  177,
      177,   18,  175,  175,  175,  175,  175,  176,  176,  176,
      176,  178,  178,  178,  178,  178,  179,  179,  189,  189,
      189,  189,   18,   18,   18,   18,   18,   18,   18,   18,
       19,   19,   19,   19,   19,   19,   19,   19,   19,   19,
       19,   19,   19,   19,   19,   19,   19,   19,   19,   19,
       19,   19,   19,   19,   19,   19,   19,   19,   19,   19,
       19,   19,   19,   19,   19,   19,   19,   19,   19,   19,
       19,   19,   19,   19,   19,   19,   19,   19,   19,   19,

       19,   19,   19,   19,   19,   19,   19,   19,   19,   19,
       19,   19,   19,   21,   21,   21,   21,   21,   21,   21,
       21,   21,   21,   21,   21,   21,   21,   21,   21,   21,
       21,   21,   21,   21,   21,   21,   21,   21,   21,   21,
       21,   21,   21,   21,   21,   21,   21,   21,   21,   21,
       21,   21,   21,   21,   21,   21,   21,   21,   21,   21,
       21,   21,   21,   21,   21,   21,   21,   21,   21,   21,
       21,   21,   21,   21,   21,   21,   23,   23,   23,  603,
       23,  153,  153,  153,  192,  192,   23,  594,  181,  181,
      181,  481,  181,  481,  153,  203,  203,  153,  181,  153,

      214,  214,  153,  292,  292,   23,  154,  154,  154,  503,
      182,  182,  182,  593,  182,  190,  190,  190,  592,  154,
      182,  201,  201,  201,  154,  303,  303,  154,  153,  587,
       23,   23,   23,   23,   23,   23,   23,   23,   24,   24,
       24,  503,   24,  186,  186,  186,  186,  186,   24,  200,
      200,  200,  200,  154,  188,  188,  188,  188,  188,  191,
      191,  191,  191,  191,  205,  205,  205,   24,  197,  197,
      197,  197,  197,  199,  199,  199,  199,  199,  202,  202,
      202,  202,  202,  206,  206,  206,  208,  208,  208,  208,
      208,  576,   24,   24,   24,   24,   24,   24,   24,   24,

       29,  207,  207,  207,  210,  210,  210,  210,  210,  468,
      468,  207,  211,  211,  211,  211,  212,  212,  212,  213,
      213,  213,  213,  213,  278,  222,  278,  222,  482,  215,
      482,  215,   29,  575,  331,  331,  331,  245,  386,  222,
      386,  215,  386,  215,  572,  215,  222,  215,  571,  280,
      245,  280,  278,   29,   29,   29,   29,   29,   29,   29,
       29,   30,  215,  280,  226,  226,  226,  245,  254,  254,
      254,  281,  295,  281,  295,  215,  226,  280,  226,  331,
      226,  281,  226,  267,  267,  267,  267,  267,  268,  268,
      268,  268,  268,   30,  281,  480,  480,  226,  488,  488,

      295,  254,  269,  269,  269,  269,  269,  333,  333,  333,
      226,  371,  371,  371,   30,   30,   30,   30,   30,   30,
       30,   30,   31,   31,   31,  566,   31,  270,  270,  270,
      270,  270,  271,  271,  271,  271,  271,  272,  272,  272,
      272,  272,  273,  273,  273,  273,  273,  279,  284,  279,
      284,  483,  333,  483,  484,  306,  484,  306,  284,  279,
      496,  296,  496,  296,  299,  565,  299,  306,  554,  306,
      335,  284,  335,  306,  299,  279,   31,   31,   31,   31,
       31,   31,   31,   31,   32,   32,   32,  299,   32,  296,
      307,  307,  307,  316,  316,  316,  316,  316,  373,  373,

      373,  306,  307,  335,  307,  374,  374,  374,  307,  317,
      317,  317,  317,  317,  532,  308,  532,  308,  311,  311,
      311,  318,  318,  318,  318,  318,  319,  319,  319,  319,
      319,  308,  567,  567,  311,  437,  307,  437,   32,   32,
       32,   32,   32,   32,   32,   32,   49,   49,  308,  437,
      552,  311,   49,  437,  551,   49,  382,  382,  382,  527,
      308,  509,  470,  311,  470,   49,   49,   49,   49,   49,
       49,   49,  527,   49,   49,   49,   49,   49,   49,   49,
       49,   49,   49,   49,   49,   49,   49,   49,   49,   68,
      470,   68,   68,  509,   68,  320,  320,  320,  320,  320,

       68,   68,  535,   68,  535,   68,   68,   68,  387,  387,
      387,   68,  547,   68,   68,   68,   68,   68,  544,  471,
       68,  471,   68,   68,   68,   68,   68,   68,   68,   68,
       68,   68,   68,   68,   68,   68,   70,  543,   70,   70,
      542,   70,  321,  321,  321,  321,  321,  539,   70,  471,
       70,  436,   70,  436,   70,  324,  324,  324,  324,  324,
      388,  388,  388,  436,   70,  538,  553,   70,  553,   70,
      325,  325,  325,  325,  325,  326,  326,  326,  326,  326,
      529,   70,   70,  297,  537,  297,  327,  327,  327,  327,
      327,  328,  328,  328,  328,  328,  329,  329,  329,  329,

      329,  339,  339,  339,  339,  339,  340,  340,  340,  340,
      340,  531,  529,  297,  341,  341,  341,  341,  341,  342,
      342,  342,  342,  342,  343,  343,  343,  343,  343,  344,
      344,  344,  344,  344,  420,  420,  420,  297,  297,  297,
      297,  297,  297,  297,  297,  348,  348,  348,  348,  348,
      349,  349,  349,  349,  349,  350,  350,  350,  350,  350,
      351,  351,  351,  351,  351,  352,  352,  352,  352,  352,
      353,  353,  353,  353,  353,  363,  363,  363,  363,  363,
      364,  364,  364,  364,  364,  365,  365,  365,  365,  365,
      366,  366,  366,  366,  366,  367,  367,  367,  367,  367,

      368,  368,  368,  368,  368,  369,  369,  369,  528,  370,
      370,  370,  394,  394,  394,  394,  394,  533,  369,  533,
      512,  369,  370,  369,  511,  510,  369,  370,  528,  533,
      370,  395,  395,  395,  395,  395,  396,  396,  396,  396,
      396,  397,  397,  397,  397,  397,  398,  398,  398,  398,
      398,  504,  369,  478,  478,  478,  370,  399,  399,  399,
      399,  399,  400,  400,  400,  487,  400,  405,  405,  405,
      405,  405,  400,  406,  406,  406,  406,  406,  407,  407,
      407,  407,  407,  408,  408,  408,  408,  408,  409,  409,
      409,  409,  409,  410,  410,  410,  410,  410,  414,  414,

      414,  414,  414,  415,  415,  415,  415,  415,  416,  416,
      416,  416,  416,  417,  417,  417,  417,  417,  418,  418,
      418,  418,  418,  419,  419,  419,  419,  419,  421,  421,
      421,  424,  424,  424,  424,  424,  486,  485,  421,  425,
      425,  425,  425,  425,  426,  426,  426,  426,  426,  427,
      427,  427,  427,  427,  428,  428,  428,  428,  428,  429,
      429,  429,  429,  429,  431,  475,  431,  442,  445,  445,
      445,  446,  446,  446,  477,  477,  477,  477,  431,  561,
      442,  561,  526,  473,  526,  431,  454,  454,  454,  454,
      454,  455,  455,  455,  455,  455,  526,  442,  456,  456,

      456,  456,  456,  526,  446,  474,  474,  474,  474,  474,
      476,  476,  476,  476,  476,  445,  479,  479,  479,  479,
      479,  490,  490,  490,  490,  490,  491,  491,  491,  491,
      491,  492,  492,  492,  492,  492,  493,  493,  493,  493,
      493,  494,  494,  494,  494,  494,  495,  495,  495,  495,
      495,  497,  497,  497,  497,  497,  498,  498,  498,  498,
      498,  499,  499,  499,  499,  499,  500,  500,  500,  500,
      500,  501,  501,  501,  501,  501,  502,  502,  502,  502,
      502,  506,  506,  506,  506,  506,  507,  507,  507,  507,
      507,  508,  508,  508,  508,  508,  513,  513,  513,  513,

      513,  514,  514,  514,  514,  514,  515,  515,  515,  515,
      515,  516,  516,  516,  516,  516,  517,  517,  517,  517,
      517,  518,  518,  518,  518,  518,  519,  519,  519,  520,
      520,  520,  520,  520,  472,  469,  519,  521,  521,  521,
      521,  521,  522,  522,  522,  522,  522,  523,  523,  523,
      523,  523,  524,  524,  524,  524,  524,  525,  525,  525,
      525,  525,  534,  536,  534,  536,  540,  541,  541,  541,
      545,  549,  562,  563,  562,  563,  534,  536,  466,  540,
      534,  536,  465,  464,  549,  555,  555,  555,  555,  555,
      564,  461,  564,  545,  460,  459,  540,  546,  546,  457,

      453,  546,  546,  546,  546,  546,  546,  546,  546,  546,
      546,  546,  546,  546,  546,  546,  546,  546,  546,  546,
      546,  546,  546,  546,  546,  546,  546,  546,  452,  546,
      546,  546,  546,  546,  546,  546,  546,  546,  546,  546,
      546,  546,  546,  546,  546,  546,  546,  546,  546,  546,
      546,  546,  546,  546,  546,  546,  546,  546,  546,  546,
      556,  556,  556,  556,  556,  557,  557,  557,  557,  557,
      558,  558,  558,  558,  558,  559,  559,  559,  559,  559,
      560,  560,  560,  560,  560,  568,  569,  568,  573,  578,
      578,  578,  582,  584,  585,  584,  585,  590,  586,  578,

      586,  451,  588,  591,  591,  591,  600,  601,  600,  601,
      590,  602,  607,  602,  607,  608,  447,  608,  569,  609,
      573,  609,  610,  441,  582,  588,  440,  590,  604,  604,
      604,  604,  604,  605,  605,  605,  605,  605,  606,  606,
      606,  606,  606,  617,  627,  617,  627,  591,  595,  595,
      595,  439,  438,  595,  610,  595,  613,  595,  595,  595,
      622,  622,  622,  433,  595,  595,  595,  595,  616,  623,
      623,  623,  432,  632,  595,  595,  595,  595,  595,  595,
      595,  595,  595,  595,  595,  628,  633,  628,  613,  595,
      430,  412,  595,  595,  595,  595,  595,  629,  391,  629,

      616,  630,  631,  630,  631,  632,  638,  390,  638,  385,
      380,  376,  375,  623,  372,  358,  337,  336,  633,  641,
      641,  641,  641,  641,  641,  641,  641,  641,  641,  641,
      641,  641,  641,  641,  641,  641,  641,  642,  642,  642,
      642,  642,  642,  642,  642,  642,  642,  642,  642,  642,
      642,  642,  642,  642,  642,  643,  643,  643,  643,  643,
      643,  643,  643,  643,  643,  643,  643,  643,  643,  643,
      643,  643,  643,  644,  644,  644,  644,  644,  644,  644,
      644,  644,  644,  644,  644,  644,  644,  644,  644,  644,
      644,  645,  645,  645,  645,  645,  645,  645,  645,  645,

      645,  645,  645,  645,  645,  645,  645,  645,  645,  646,
      646,  646,  646,  646,  646,  646,  646,  646,  646,  646,
      646,  646,  646,  646,  646,  646,  646,  647,  647,  647,
      647,  647,  647,  647,  647,  647,  647,  647,  647,  647,
      647,  647,  647,  647,  647,  648,  648,  648,  648,  648,
      648,  648,  648,  648,  648,  648,  648,  648,  648,  648,
      648,  648,  648,  649,  649,  649,  649,  649,  649,  649,
      649,  649,  649,  649,  649,  649,  649,  649,  649,  649,
      649,  650,  312,  650,  650,  310,  309,  650,  302,  301,
      298,  291,  650,  651,  651,  651,  651,  290,  651,  651,

      651,  651,  651,  651,  651,  651,  651,  651,  651,  651,
      651,  652,  652,  652,  652,  652,  652,  652,  652,  652,
      652,  652,  652,  652,  652,  289,  652,  652,  652,  653,
      653,  288,  286,  653,  653,  653,  653,  653,  653,  653,
      653,  653,  653,  653,  285,  653,  653,  654,  283,  654,
      282,  276,  654,  655,  275,  262,  261,  260,  259,  256,
      655,  255,  239,  655,  655,  656,  656,  656,  656,  656,
      656,  656,  656,  656,  656,  656,  656,  656,  656,  656,
      656,  656,  656,  657,  657,  657,  657,  657,  657,  657,
      657,  657,  657,  657,  657,  657,  657,  657,  657,  657,

      657,  658,  238,  658,  237,  236,  658,  659,  659,  659,
      659,  233,  659,  659,  659,  659,  659,  659,  659,  659,
      659,  659,  659,  659,  659,  661,  661,  661,  232,  225,
      661,  661,  224,  661,  662,  662,  662,  662,  662,  662,
      662,  662,  662,  662,  662,  662,  662,  662,  223,  662,
      662,  662,  663,  220,  663,  219,  218,  217,  663,  216,
      209,  198,  663,  663,  196,  663,  187,  185,  663,  664,
      664,  664,  664,  664,  664,  664,  664,  664,  664,  664,
      664,  664,  664,  174,  664,  664,  664,  665,  665,  665,
      665,  665,  665,  665,  665,  665,  665,  665,  665,  665,

      665,  172,  665,  665,  665,  667,  667,  667,  169,  168,
      667,  669,  669,  669,  160,  159,  669,  158,  156,  146,
      669,  671,  140,  139,  131,  671,  671,  128,  671,  672,
      672,  672,  127,  120,  672,  118,  101,   95,  672,  674,
      674,  674,   93,   92,  674,   91,   81,   80,  674,  676,
      676,  676,   78,   77,  676,  676,   71,  676,  678,  678,
      678,   61,   59,  678,  680,  680,  680,   56,   55,  680,
       54,   53,   52,  680,  681,  681,  681,  681,  681,  681,
      681,  681,  681,  681,   51,  681,  681,  681,   48,  681,
      681,  681,  682,  682,  682,   46,   44,  682,   43,   42,

       40,  682,  683,  683,  683,   39,   38,  683,   33,   28,
       27,  683,  640,  640,  640,  640,  640,  640,  640,  640,
      640,  640,  640,  640,  640,  640,  640,  640,  640,  640,
      640,  640,  640,  640,  640,  640,  640,  640,  640,  640,
      640,  640,  640,  640,  640,  640,  640,  640,  640,  640,
      640,  640,  640,  640,  640,  640,  640,  640,  640,  640,
      640,  640,  640,  640,  640,  640,  640,  640,  640,  640,
      640,  640,  640,  640,  640,  640
    } ;

/* Table of booleans, true if rule could match eol. */
static const flex_int32_t yy_rule_can_match_eol[139] =
    {   0,
0, 0, 0, 1, 0, 0, 1, 0, 0, 0, 1, 1, 0, 1, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 
    1, 0, 1, 0, 0, 0, 1, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 1, 0, 0, 0, 0, 0, 1, 1, 0, 0, 0, 0, 1, 1, 1, 1, 0, 0, 0, 
    1, 1, 0, 0, 0, 0, 0, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 1, 1, 
    0, 0, 1, 1, 0, 1, 0, 1, 1, 1, 1, 0, 1, 1, 1, 1, 0, 1, 0, 1, 
    1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0,     };

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
#line 1 "/home/runner/work/lukeparser/lukeparser/src/luke/parser/compiled/tmp.l"
#line 9 "/home/runner/work/lukeparser/lukeparser/src/luke/parser/compiled/tmp.l"
#include "tmp.tab.h"

// chars to replace
const char *chr_sqr_open = (char *)"[\0";
const char *chr_sqr_close = (char *)"]\0";
const char *chr_rnd_open = (char *)"(\0";
const char *chr_rnd_close = (char *)")\0";
const char *chr_curly_open = (char *)"{\0";
const char *chr_bs_curly_open = (char *)"\\{\0";
const char *chr_curly_close = (char *)"}\0";
const char *chr_bs_curly_close = (char *)"\\}\0";
const char *chr_hash = (char *)"#\0";
const char *chr_star = (char *)"*\0";
const char *chr_tri_close = (char *)">\0";
const char *chr_tri_open = (char *)"<\0";
const char *chr_minus = (char *)"-\0";
const char *chr_underscore = (char *)"_\0";
const char *chr_dollar = (char *)"$\0";
const char *chr_backtick = (char *)"`\0";
const char *chr_backslash = (char *)"\\\0";
const char *chr_bs_backslash = (char *)"\\\\\0";
const char *chr_pipe = (char *)"|\0";
const char *chr_emdash = (char *)"\xE2\x80\x94\0";
const char *chr_space = (char *)" \0";
const char *chr_newline = (char *)"\n\0";

// attribute/input-stack
// printf("Push State -> index:%d state:%d\n",ais_i,state);
// printf("Current State -> index:%d state:%d\n",ais_i,ais[ais_i]);
int ais[10000];
int ais_i = -1;
#define STATE_PUSH(state) \
    ais_i++; \
    ais[ais_i] = state; \
    BEGIN(state);

#define STATE_POP() \
    ais_i--; \
    if(ais_i<0) { \
        ais_i = -1; \
        BEGIN(INITIAL);  \
    } else { \
        BEGIN(ais[ais_i]); \
    }


// emph strong strike - state
char ess[5] = {0,0,0,0,0};
int ess_i = 0;
#define ess_state_stack(char,start_sym,end_sym) \
    if(ess_i==0 || ess[ess_i-1] != char) { \
        ess[ess_i] = char; \
        ess_i++; \
        returntoken(start_sym);  \
    } else { \
        ess_i--; \
        returntoken(end_sym); \
    }

#define reset_stacks() \
        ais_i=-1; \
        ess_i=0;

#define YY_USER_ACTION                                                     \
  yylloc->first_line = yylloc->last_line;                                  \
  yylloc->first_column = yylloc->last_column;                              \
  if (yylloc->first_line == yyget_lineno(yyscanner))                       \
     yylloc->last_column += yyget_leng(yyscanner);                         \
  else {                                                                   \
     int col;                                                              \
     for (col = 1; yyget_text(yyscanner)[yyget_leng(yyscanner) - col] != '\n'; ++col) {}                                  \
     yylloc->last_column = col;                                            \
     yylloc->last_line = yyget_lineno(yyscanner);                          \
  }


#include <stdio.h>
#include <string.h>
#include "Python.h"
#include "tmp.tab.h"
extern void *py_parser;
extern void (*py_input)(PyObject *parser, char *buf, int *result, int max_size);

PyMODINIT_FUNC PyInit_markdown_parser(void) { /* windows needs this function */ }

// https://stackoverflow.com/questions/42434603/how-can-flex-return-multiple-terminals-at-one-time
#define returntoken(tok)                                       \
        *yylval = (void*)PyUnicode_FromString(strdup(yytext)); \
        return tok;
#define returntokenFromString(str, tok)                        \
        *yylval = (void*)strdup(str);                          \
        return tok;
#define YY_INPUT(buf,result,max_size) {                        \
    (*py_input)(py_parser, buf, &result, max_size);            \
}
#line 1333 "lex.yy.c"

#line 1335 "lex.yy.c"

#define INITIAL 0
#define EMPH_STATE 1
#define STRONG_STATE 2
#define STRIKE_STATE 3
#define ML_COMMENT 4
#define COMMENT 5
#define CODEBLOCK_STATE 6
#define CODEBLOCK_STATE_VERBATIM 7
#define CODEINLINE_STATE 8
#define MATHINLINE_STATE 9
#define ATTRIBUTE_STATE 10
#define HYPERREF_LINK_STATE 11
#define HYPERREF_DEFINITION 12
#define HEADINGHASH_STATE 13
#define HYPERREF_CODE_STATE 14
#define HYPERREF_LINK_ALT_STATE 15

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#define YY_EXTRA_TYPE int

/* Holds the entire state of the reentrant scanner. */
struct yyguts_t
    {

    /* User-defined. Not touched by flex. */
    YY_EXTRA_TYPE yyextra_r;

    /* The rest are the same as the globals declared in the non-reentrant scanner. */
    FILE *yyin_r, *yyout_r;
    size_t yy_buffer_stack_top; /**< index of top of stack. */
    size_t yy_buffer_stack_max; /**< capacity of stack. */
    YY_BUFFER_STATE * yy_buffer_stack; /**< Stack as an array. */
    char yy_hold_char;
    int yy_n_chars;
    int yyleng_r;
    char *yy_c_buf_p;
    int yy_init;
    int yy_start;
    int yy_did_buffer_switch_on_eof;
    int yy_start_stack_ptr;
    int yy_start_stack_depth;
    int *yy_start_stack;
    yy_state_type yy_last_accepting_state;
    char* yy_last_accepting_cpos;

    int yylineno_r;
    int yy_flex_debug_r;

    char *yytext_r;
    int yy_more_flag;
    int yy_more_len;

    YYSTYPE * yylval_r;

    YYLTYPE * yylloc_r;

    }; /* end struct yyguts_t */

static int yy_init_globals ( yyscan_t yyscanner );

    /* This must go here because YYSTYPE and YYLTYPE are included
     * from bison output in section 1.*/
    #    define yylval yyg->yylval_r
    
    #    define yylloc yyg->yylloc_r
    
int yylex_init (yyscan_t* scanner);

int yylex_init_extra ( YY_EXTRA_TYPE user_defined, yyscan_t* scanner);

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int yylex_destroy ( yyscan_t yyscanner );

int yyget_debug ( yyscan_t yyscanner );

void yyset_debug ( int debug_flag , yyscan_t yyscanner );

YY_EXTRA_TYPE yyget_extra ( yyscan_t yyscanner );

void yyset_extra ( YY_EXTRA_TYPE user_defined , yyscan_t yyscanner );

FILE *yyget_in ( yyscan_t yyscanner );

void yyset_in  ( FILE * _in_str , yyscan_t yyscanner );

FILE *yyget_out ( yyscan_t yyscanner );

void yyset_out  ( FILE * _out_str , yyscan_t yyscanner );

			int yyget_leng ( yyscan_t yyscanner );

char *yyget_text ( yyscan_t yyscanner );

int yyget_lineno ( yyscan_t yyscanner );

void yyset_lineno ( int _line_number , yyscan_t yyscanner );

int yyget_column  ( yyscan_t yyscanner );

void yyset_column ( int _column_no , yyscan_t yyscanner );

YYSTYPE * yyget_lval ( yyscan_t yyscanner );

void yyset_lval ( YYSTYPE * yylval_param , yyscan_t yyscanner );

       YYLTYPE *yyget_lloc ( yyscan_t yyscanner );
    
        void yyset_lloc ( YYLTYPE * yylloc_param , yyscan_t yyscanner );
    
/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int yywrap ( yyscan_t yyscanner );
#else
extern int yywrap ( yyscan_t yyscanner );
#endif
#endif

#ifndef YY_NO_UNPUT
    
    static void yyunput ( int c, char *buf_ptr  , yyscan_t yyscanner);
    
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy ( char *, const char *, int , yyscan_t yyscanner);
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen ( const char * , yyscan_t yyscanner);
#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
static int yyinput ( yyscan_t yyscanner );
#else
static int input ( yyscan_t yyscanner );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k */
#define YY_READ_BUF_SIZE 16384
#else
#define YY_READ_BUF_SIZE 8192
#endif /* __ia64__ */
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( yytext, (size_t) yyleng, 1, yyout )) {} } while (0)
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		int n; \
		for ( n = 0; n < max_size && \
			     (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = (int) fread(buf, 1, (yy_size_t) max_size, yyin)) == 0 && ferror(yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(yyin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg , yyscanner)
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int yylex \
               (YYSTYPE * yylval_param, YYLTYPE * yylloc_param , yyscan_t yyscanner);

#define YY_DECL int yylex \
               (YYSTYPE * yylval_param, YYLTYPE * yylloc_param , yyscan_t yyscanner)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK /*LINTED*/break;
#endif

#define YY_RULE_SETUP \
	if ( yyleng > 0 ) \
		YY_CURRENT_BUFFER_LVALUE->yy_at_bol = \
				(yytext[yyleng - 1] == '\n'); \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	yy_state_type yy_current_state;
	char *yy_cp, *yy_bp;
	int yy_act;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

    yylval = yylval_param;

    yylloc = yylloc_param;

	if ( !yyg->yy_init )
		{
		yyg->yy_init = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! yyg->yy_start )
			yyg->yy_start = 1;	/* first start state */

		if ( ! yyin )
			yyin = stdin;

		if ( ! yyout )
			yyout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			yyensure_buffer_stack (yyscanner);
			YY_CURRENT_BUFFER_LVALUE =
				yy_create_buffer( yyin, YY_BUF_SIZE , yyscanner);
		}

		yy_load_buffer_state( yyscanner );
		}

	{
#line 124 "/home/runner/work/lukeparser/lukeparser/src/luke/parser/compiled/tmp.l"

#line 126 "/home/runner/work/lukeparser/lukeparser/src/luke/parser/compiled/tmp.l"
    if (yyget_extra(yyscanner)) {
          return 0;
    }
    yyset_extra(0,yyscanner);

#line 1643 "lex.yy.c"

	while ( /*CONSTCOND*/1 )		/* loops until end-of-file is reached */
		{
		yy_cp = yyg->yy_c_buf_p;

		/* Support of yytext. */
		*yy_cp = yyg->yy_hold_char;

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = yyg->yy_start;
		yy_current_state += YY_AT_BOL();
yy_match:
		do
			{
			YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)] ;
			if ( yy_accept[yy_current_state] )
				{
				yyg->yy_last_accepting_state = yy_current_state;
				yyg->yy_last_accepting_cpos = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 641 )
					yy_c = yy_meta[yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
			++yy_cp;
			}
		while ( yy_current_state != 640 );
		yy_cp = yyg->yy_last_accepting_cpos;
		yy_current_state = yyg->yy_last_accepting_state;

yy_find_action:
		yy_act = yy_accept[yy_current_state];

		YY_DO_BEFORE_ACTION;

		if ( yy_act != YY_END_OF_BUFFER && yy_rule_can_match_eol[yy_act] )
			{
			int yyl;
			for ( yyl = 0; yyl < yyleng; ++yyl )
				if ( yytext[yyl] == '\n' )
					
    do{ yylineno++;
        yycolumn=0;
    }while(0)
;
			}

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = yyg->yy_hold_char;
			yy_cp = yyg->yy_last_accepting_cpos;
			yy_current_state = yyg->yy_last_accepting_state;
			goto yy_find_action;

case 1:
YY_RULE_SETUP
#line 131 "/home/runner/work/lukeparser/lukeparser/src/luke/parser/compiled/tmp.l"
{ STATE_PUSH(ML_COMMENT); }
	YY_BREAK
case 2:
YY_RULE_SETUP
#line 132 "/home/runner/work/lukeparser/lukeparser/src/luke/parser/compiled/tmp.l"
{ STATE_PUSH(ML_COMMENT); }
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 133 "/home/runner/work/lukeparser/lukeparser/src/luke/parser/compiled/tmp.l"
{ STATE_POP(); }
	YY_BREAK
case 4:
/* rule 4 can match eol */
YY_RULE_SETUP
#line 134 "/home/runner/work/lukeparser/lukeparser/src/luke/parser/compiled/tmp.l"
{ }
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 135 "/home/runner/work/lukeparser/lukeparser/src/luke/parser/compiled/tmp.l"
{ }
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 136 "/home/runner/work/lukeparser/lukeparser/src/luke/parser/compiled/tmp.l"
{ STATE_PUSH(COMMENT); }
	YY_BREAK
case 7:
/* rule 7 can match eol */
*yy_cp = yyg->yy_hold_char; /* undo effects of setting up yytext */
YY_LINENO_REWIND_TO(yy_bp + 1);
yyg->yy_c_buf_p = yy_cp = yy_bp + 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 137 "/home/runner/work/lukeparser/lukeparser/src/luke/parser/compiled/tmp.l"
{ STATE_POP(); }
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 138 "/home/runner/work/lukeparser/lukeparser/src/luke/parser/compiled/tmp.l"
{ }
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 139 "/home/runner/work/lukeparser/lukeparser/src/luke/parser/compiled/tmp.l"
{ STATE_PUSH(ML_COMMENT); }
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 140 "/home/runner/work/lukeparser/lukeparser/src/luke/parser/compiled/tmp.l"
{ STATE_PUSH(COMMENT); }
	YY_BREAK
case 11:
/* rule 11 can match eol */
YY_RULE_SETUP
#line 142 "/home/runner/work/lukeparser/lukeparser/src/luke/parser/compiled/tmp.l"
{ returntoken( BR ); }
	YY_BREAK
case 12:
/* rule 12 can match eol */
YY_RULE_SETUP
#line 143 "/home/runner/work/lukeparser/lukeparser/src/luke/parser/compiled/tmp.l"
{ returntoken( NEWLINE ); }
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 144 "/home/runner/work/lukeparser/lukeparser/src/luke/parser/compiled/tmp.l"
{ returntoken(URL); }
	YY_BREAK
case 14:
/* rule 14 can match eol */
YY_RULE_SETUP
#line 145 "/home/runner/work/lukeparser/lukeparser/src/luke/parser/compiled/tmp.l"
{ returntoken(URL); }
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 147 "/home/runner/work/lukeparser/lukeparser/src/luke/parser/compiled/tmp.l"
{ returntokenFromString(chr_sqr_open, CHAR); }
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 148 "/home/runner/work/lukeparser/lukeparser/src/luke/parser/compiled/tmp.l"
{ returntokenFromString(chr_sqr_close, CHAR); }
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 149 "/home/runner/work/lukeparser/lukeparser/src/luke/parser/compiled/tmp.l"
{ returntokenFromString(chr_curly_open, CHAR); }
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 150 "/home/runner/work/lukeparser/lukeparser/src/luke/parser/compiled/tmp.l"
{ returntokenFromString(chr_curly_close, CHAR); }
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 151 "/home/runner/work/lukeparser/lukeparser/src/luke/parser/compiled/tmp.l"
{ returntokenFromString(chr_hash, CHAR); }
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 152 "/home/runner/work/lukeparser/lukeparser/src/luke/parser/compiled/tmp.l"
{ returntokenFromString(chr_star, CHAR); }
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 153 "/home/runner/work/lukeparser/lukeparser/src/luke/parser/compiled/tmp.l"
{ returntokenFromString(chr_minus, CHAR); }
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 154 "/home/runner/work/lukeparser/lukeparser/src/luke/parser/compiled/tmp.l"
{ returntokenFromString(chr_underscore, CHAR); }
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 155 "/home/runner/work/lukeparser/lukeparser/src/luke/parser/compiled/tmp.l"
{ returntokenFromString(chr_dollar, CHAR); }
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 156 "/home/runner/work/lukeparser/lukeparser/src/luke/parser/compiled/tmp.l"
{ returntokenFromString(chr_pipe, CHAR); }
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 157 "/home/runner/work/lukeparser/lukeparser/src/luke/parser/compiled/tmp.l"
{ returntokenFromString(chr_backtick, CHAR); }
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 158 "/home/runner/work/lukeparser/lukeparser/src/luke/parser/compiled/tmp.l"
{ returntokenFromString(chr_backslash, CHAR); }
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 159 "/home/runner/work/lukeparser/lukeparser/src/luke/parser/compiled/tmp.l"
{ returntokenFromString(chr_emdash, CHAR); }
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 161 "/home/runner/work/lukeparser/lukeparser/src/luke/parser/compiled/tmp.l"
{ returntoken(MATHBLOCK_VERBATIM_PLACEHOLDER); }
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 162 "/home/runner/work/lukeparser/lukeparser/src/luke/parser/compiled/tmp.l"
{ returntoken(PLACEHOLDER); }
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 163 "/home/runner/work/lukeparser/lukeparser/src/luke/parser/compiled/tmp.l"
{ returntoken(LATEX_COMMAND); }
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 164 "/home/runner/work/lukeparser/lukeparser/src/luke/parser/compiled/tmp.l"
{ returntoken(LATEX_COMMAND_WITH_ARGUMENTS); }
	YY_BREAK
case 32:
/* rule 32 can match eol */
YY_RULE_SETUP
#line 165 "/home/runner/work/lukeparser/lukeparser/src/luke/parser/compiled/tmp.l"
{ STATE_PUSH(ATTRIBUTE_STATE); returntoken(LATEX_COMMAND_WITH_OPTIONAL_ARGUMENT); }
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 167 "/home/runner/work/lukeparser/lukeparser/src/luke/parser/compiled/tmp.l"
{ returntoken(TABLE_DELIM); }
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 168 "/home/runner/work/lukeparser/lukeparser/src/luke/parser/compiled/tmp.l"
{ returntoken(TABLE_HRULE); }
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 169 "/home/runner/work/lukeparser/lukeparser/src/luke/parser/compiled/tmp.l"
{ returntoken(TABLE_HRULE_LEFT_ALIGNED); }
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 170 "/home/runner/work/lukeparser/lukeparser/src/luke/parser/compiled/tmp.l"
{ returntoken(TABLE_HRULE_CENTERED); }
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 171 "/home/runner/work/lukeparser/lukeparser/src/luke/parser/compiled/tmp.l"
{ returntoken(TABLE_HRULE_RIGHT_ALIGNED); }
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 173 "/home/runner/work/lukeparser/lukeparser/src/luke/parser/compiled/tmp.l"
{ STATE_PUSH(CODEBLOCK_STATE); returntoken(CODEBLOCK_START); }
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 174 "/home/runner/work/lukeparser/lukeparser/src/luke/parser/compiled/tmp.l"
{ STATE_PUSH(ATTRIBUTE_STATE); returntoken(ATTR_START); }
	YY_BREAK
case 40:
/* rule 40 can match eol */
YY_RULE_SETUP
#line 175 "/home/runner/work/lukeparser/lukeparser/src/luke/parser/compiled/tmp.l"
{ STATE_PUSH(CODEBLOCK_STATE_VERBATIM); returntoken(CODEBLOCK_BR); }
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 176 "/home/runner/work/lukeparser/lukeparser/src/luke/parser/compiled/tmp.l"
{ returntoken(CODEBLOCK_STRING_BEFORE); }
	YY_BREAK
case 42:
/* rule 42 can match eol */
YY_RULE_SETUP
#line 177 "/home/runner/work/lukeparser/lukeparser/src/luke/parser/compiled/tmp.l"
{ returntokenFromString(yytext,CODEBLOCK_CHAR); }
	YY_BREAK
case 43:
YY_RULE_SETUP
#line 178 "/home/runner/work/lukeparser/lukeparser/src/luke/parser/compiled/tmp.l"
{ STATE_POP(); STATE_POP(); returntoken(CODEBLOCK_END); }
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 179 "/home/runner/work/lukeparser/lukeparser/src/luke/parser/compiled/tmp.l"
{ returntokenFromString(yytext,CODEBLOCK_CHAR); }
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 181 "/home/runner/work/lukeparser/lukeparser/src/luke/parser/compiled/tmp.l"
{ STATE_PUSH(CODEINLINE_STATE); returntoken(CODEINLINE_START); }
	YY_BREAK
case 46:
/* rule 46 can match eol */
YY_RULE_SETUP
#line 182 "/home/runner/work/lukeparser/lukeparser/src/luke/parser/compiled/tmp.l"
{ returntokenFromString(yytext,CODEINLINE_CHAR); }
	YY_BREAK
case 47:
YY_RULE_SETUP
#line 183 "/home/runner/work/lukeparser/lukeparser/src/luke/parser/compiled/tmp.l"
{ STATE_POP(); returntoken(CODEINLINE_END); }
	YY_BREAK
case 48:
/* rule 48 can match eol */
YY_RULE_SETUP
#line 184 "/home/runner/work/lukeparser/lukeparser/src/luke/parser/compiled/tmp.l"
{ STATE_POP(); returntoken(CODEINLINE_END); }
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 185 "/home/runner/work/lukeparser/lukeparser/src/luke/parser/compiled/tmp.l"
{ returntokenFromString(yytext,CODEINLINE_CHAR); }
	YY_BREAK
case 50:
YY_RULE_SETUP
#line 186 "/home/runner/work/lukeparser/lukeparser/src/luke/parser/compiled/tmp.l"
{ returntokenFromString(yytext,CODEINLINE_CHAR); }
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 188 "/home/runner/work/lukeparser/lukeparser/src/luke/parser/compiled/tmp.l"
{ STATE_PUSH(MATHINLINE_STATE); returntoken(MATHBLOCK_START); }
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 189 "/home/runner/work/lukeparser/lukeparser/src/luke/parser/compiled/tmp.l"
{ STATE_PUSH(MATHINLINE_STATE); returntoken(MATHINLINE_START); }
	YY_BREAK
case 53:
YY_RULE_SETUP
#line 190 "/home/runner/work/lukeparser/lukeparser/src/luke/parser/compiled/tmp.l"
{ returntokenFromString(chr_bs_curly_open, MATHBLOCK_CHAR); }
	YY_BREAK
case 54:
YY_RULE_SETUP
#line 191 "/home/runner/work/lukeparser/lukeparser/src/luke/parser/compiled/tmp.l"
{ returntokenFromString(chr_bs_curly_close, MATHBLOCK_CHAR); }
	YY_BREAK
case 55:
YY_RULE_SETUP
#line 192 "/home/runner/work/lukeparser/lukeparser/src/luke/parser/compiled/tmp.l"
{ returntokenFromString(chr_dollar, MATHBLOCK_CHAR); }
	YY_BREAK
case 56:
YY_RULE_SETUP
#line 193 "/home/runner/work/lukeparser/lukeparser/src/luke/parser/compiled/tmp.l"
{ returntokenFromString(chr_bs_backslash, MATHBLOCK_CHAR); }
	YY_BREAK
case 57:
YY_RULE_SETUP
#line 194 "/home/runner/work/lukeparser/lukeparser/src/luke/parser/compiled/tmp.l"
{ returntoken(MATHBLOCK_LATEX_COMMAND); }
	YY_BREAK
case 58:
YY_RULE_SETUP
#line 195 "/home/runner/work/lukeparser/lukeparser/src/luke/parser/compiled/tmp.l"
{ returntoken(MATHBLOCK_CURLY_OPEN); }
	YY_BREAK
case 59:
YY_RULE_SETUP
#line 196 "/home/runner/work/lukeparser/lukeparser/src/luke/parser/compiled/tmp.l"
{ returntoken(MATHBLOCK_CURLY_CLOSE); }
	YY_BREAK
case 60:
YY_RULE_SETUP
#line 197 "/home/runner/work/lukeparser/lukeparser/src/luke/parser/compiled/tmp.l"
{ returntokenFromString(yytext, MATHBLOCK_CHAR); }
	YY_BREAK
case 61:
/* rule 61 can match eol */
YY_RULE_SETUP
#line 198 "/home/runner/work/lukeparser/lukeparser/src/luke/parser/compiled/tmp.l"
{ returntokenFromString(yytext, MATHBLOCK_CHAR); }
	YY_BREAK
case 62:
YY_RULE_SETUP
#line 199 "/home/runner/work/lukeparser/lukeparser/src/luke/parser/compiled/tmp.l"
{ STATE_POP(); returntoken(MATH_END); }
	YY_BREAK
case 63:
YY_RULE_SETUP
#line 200 "/home/runner/work/lukeparser/lukeparser/src/luke/parser/compiled/tmp.l"
{ returntokenFromString(yytext, MATHBLOCK_CHAR); }
	YY_BREAK
case 64:
YY_RULE_SETUP
#line 202 "/home/runner/work/lukeparser/lukeparser/src/luke/parser/compiled/tmp.l"
{ STATE_PUSH(ATTRIBUTE_STATE); returntoken(ATTR_START); }
	YY_BREAK
case 65:
YY_RULE_SETUP
#line 203 "/home/runner/work/lukeparser/lukeparser/src/luke/parser/compiled/tmp.l"
{ STATE_PUSH(ATTRIBUTE_STATE); returntoken(ATTR_START); }
	YY_BREAK
case 66:
YY_RULE_SETUP
#line 204 "/home/runner/work/lukeparser/lukeparser/src/luke/parser/compiled/tmp.l"
{ STATE_PUSH(ATTRIBUTE_STATE); returntoken(ATTR_START); }
	YY_BREAK
case 67:
/* rule 67 can match eol */
YY_RULE_SETUP
#line 205 "/home/runner/work/lukeparser/lukeparser/src/luke/parser/compiled/tmp.l"
{ STATE_POP(); returntoken(ATTR_END); }
	YY_BREAK
case 68:
/* rule 68 can match eol */
YY_RULE_SETUP
#line 206 "/home/runner/work/lukeparser/lukeparser/src/luke/parser/compiled/tmp.l"
{ STATE_POP(); returntoken(ATTR_END_AND_ARG_START); }
	YY_BREAK
case 69:
YY_RULE_SETUP
#line 207 "/home/runner/work/lukeparser/lukeparser/src/luke/parser/compiled/tmp.l"
{ STATE_PUSH(INITIAL); returntoken(ATTR_INPUT); }
	YY_BREAK
case 70:
YY_RULE_SETUP
#line 208 "/home/runner/work/lukeparser/lukeparser/src/luke/parser/compiled/tmp.l"
{ returntoken(ATTR_HASH); }
	YY_BREAK
case 71:
YY_RULE_SETUP
#line 209 "/home/runner/work/lukeparser/lukeparser/src/luke/parser/compiled/tmp.l"
{ returntoken(ATTR_DOT); }
	YY_BREAK
case 72:
YY_RULE_SETUP
#line 210 "/home/runner/work/lukeparser/lukeparser/src/luke/parser/compiled/tmp.l"
{ returntoken(ATTR_EXCLAMATION); }
	YY_BREAK
case 73:
/* rule 73 can match eol */
YY_RULE_SETUP
#line 211 "/home/runner/work/lukeparser/lukeparser/src/luke/parser/compiled/tmp.l"
{ returntoken(ATTR_EQUAL); }
	YY_BREAK
case 74:
/* rule 74 can match eol */
YY_RULE_SETUP
#line 212 "/home/runner/work/lukeparser/lukeparser/src/luke/parser/compiled/tmp.l"
{ returntoken(ATTR_EQUAL); }
	YY_BREAK
case 75:
/* rule 75 can match eol */
YY_RULE_SETUP
#line 213 "/home/runner/work/lukeparser/lukeparser/src/luke/parser/compiled/tmp.l"
{ returntoken(ATTR_COMMA); }
	YY_BREAK
case 76:
/* rule 76 can match eol */
YY_RULE_SETUP
#line 214 "/home/runner/work/lukeparser/lukeparser/src/luke/parser/compiled/tmp.l"
{ returntoken(ATTR_COMMA); }
	YY_BREAK
case 77:
YY_RULE_SETUP
#line 215 "/home/runner/work/lukeparser/lukeparser/src/luke/parser/compiled/tmp.l"
{ returntoken(ATTR_BOOLEAN); }
	YY_BREAK
case 78:
YY_RULE_SETUP
#line 216 "/home/runner/work/lukeparser/lukeparser/src/luke/parser/compiled/tmp.l"
{ returntoken(ATTR_BOOLEAN); }
	YY_BREAK
case 79:
YY_RULE_SETUP
#line 217 "/home/runner/work/lukeparser/lukeparser/src/luke/parser/compiled/tmp.l"
{ returntoken(ATTR_NUMBER); }
	YY_BREAK
case 80:
/* rule 80 can match eol */
YY_RULE_SETUP
#line 218 "/home/runner/work/lukeparser/lukeparser/src/luke/parser/compiled/tmp.l"
{ returntoken(ATTR_STRING); }
	YY_BREAK
case 81:
/* rule 81 can match eol */
YY_RULE_SETUP
#line 219 "/home/runner/work/lukeparser/lukeparser/src/luke/parser/compiled/tmp.l"
{ returntoken(ATTR_STRING); }
	YY_BREAK
case 82:
YY_RULE_SETUP
#line 220 "/home/runner/work/lukeparser/lukeparser/src/luke/parser/compiled/tmp.l"
{ returntoken(ATTR_PLACEHOLDER); }
	YY_BREAK
case 83:
YY_RULE_SETUP
#line 221 "/home/runner/work/lukeparser/lukeparser/src/luke/parser/compiled/tmp.l"
{ STATE_PUSH(MATHINLINE_STATE); returntoken(MATHBLOCK_START); }
	YY_BREAK
case 84:
YY_RULE_SETUP
#line 222 "/home/runner/work/lukeparser/lukeparser/src/luke/parser/compiled/tmp.l"
{ STATE_PUSH(MATHINLINE_STATE); returntoken(MATHINLINE_START); }
	YY_BREAK
case 85:
YY_RULE_SETUP
#line 223 "/home/runner/work/lukeparser/lukeparser/src/luke/parser/compiled/tmp.l"
{ returntoken(ATTR_WORD); }
	YY_BREAK
case 86:
YY_RULE_SETUP
#line 224 "/home/runner/work/lukeparser/lukeparser/src/luke/parser/compiled/tmp.l"
{ }
	YY_BREAK
case 87:
/* rule 87 can match eol */
YY_RULE_SETUP
#line 227 "/home/runner/work/lukeparser/lukeparser/src/luke/parser/compiled/tmp.l"
{ returntoken(FOOTNOTE_DEFINITION); }
	YY_BREAK
case 88:
/* rule 88 can match eol */
YY_RULE_SETUP
#line 228 "/home/runner/work/lukeparser/lukeparser/src/luke/parser/compiled/tmp.l"
{ returntoken(FOOTNOTE_DEFINITION); }
	YY_BREAK
case 89:
/* rule 89 can match eol */
YY_RULE_SETUP
#line 229 "/home/runner/work/lukeparser/lukeparser/src/luke/parser/compiled/tmp.l"
{ returntoken(IMAGE_DEFINITION); }
	YY_BREAK
case 90:
/* rule 90 can match eol */
YY_RULE_SETUP
#line 230 "/home/runner/work/lukeparser/lukeparser/src/luke/parser/compiled/tmp.l"
{ returntoken(LINK_DEFINITION); }
	YY_BREAK
case 91:
YY_RULE_SETUP
#line 231 "/home/runner/work/lukeparser/lukeparser/src/luke/parser/compiled/tmp.l"
{ returntoken(FOOTNOTE_START); }
	YY_BREAK
case 92:
YY_RULE_SETUP
#line 232 "/home/runner/work/lukeparser/lukeparser/src/luke/parser/compiled/tmp.l"
{ returntoken(FOOTNOTE_MID); }
	YY_BREAK
case 93:
YY_RULE_SETUP
#line 233 "/home/runner/work/lukeparser/lukeparser/src/luke/parser/compiled/tmp.l"
{ returntoken(FOOTNOTE_INLINE_START); }
	YY_BREAK
case 94:
YY_RULE_SETUP
#line 234 "/home/runner/work/lukeparser/lukeparser/src/luke/parser/compiled/tmp.l"
{ returntoken(FOOTNOTE_INLINE_MID); }
	YY_BREAK
case 95:
YY_RULE_SETUP
#line 235 "/home/runner/work/lukeparser/lukeparser/src/luke/parser/compiled/tmp.l"
{ returntoken(IMG_START); }
	YY_BREAK
case 96:
YY_RULE_SETUP
#line 236 "/home/runner/work/lukeparser/lukeparser/src/luke/parser/compiled/tmp.l"
{ returntoken(LINK_START); }
	YY_BREAK
case 97:
YY_RULE_SETUP
#line 237 "/home/runner/work/lukeparser/lukeparser/src/luke/parser/compiled/tmp.l"
{ returntoken(HYPERREF_REF_MID); }
	YY_BREAK
case 98:
/* rule 98 can match eol */
YY_RULE_SETUP
#line 238 "/home/runner/work/lukeparser/lukeparser/src/luke/parser/compiled/tmp.l"
{  STATE_PUSH(HYPERREF_CODE_STATE); returntoken(HYPERREF_CODE_START); }
	YY_BREAK
case 99:
/* rule 99 can match eol */
YY_RULE_SETUP
#line 239 "/home/runner/work/lukeparser/lukeparser/src/luke/parser/compiled/tmp.l"
{ STATE_PUSH(HYPERREF_LINK_STATE); returntoken(HYPERREF_LINK_MID); }
	YY_BREAK
case 100:
YY_RULE_SETUP
#line 240 "/home/runner/work/lukeparser/lukeparser/src/luke/parser/compiled/tmp.l"
{ STATE_POP(); returntoken(HYPERREF_REF_END); }
	YY_BREAK
case 101:
YY_RULE_SETUP
#line 242 "/home/runner/work/lukeparser/lukeparser/src/luke/parser/compiled/tmp.l"
{ returntokenFromString(chr_rnd_close, HYPERREF_LINK_CHAR); }
	YY_BREAK
case 102:
/* rule 102 can match eol */
YY_RULE_SETUP
#line 243 "/home/runner/work/lukeparser/lukeparser/src/luke/parser/compiled/tmp.l"
{ STATE_POP(); returntoken(HYPERREF_LINK_END); }
	YY_BREAK
case 103:
/* rule 103 can match eol */
YY_RULE_SETUP
#line 244 "/home/runner/work/lukeparser/lukeparser/src/luke/parser/compiled/tmp.l"
{ STATE_POP(); STATE_PUSH(HYPERREF_LINK_ALT_STATE); returntoken(HYPERREF_LINK_ALT_START); }
	YY_BREAK
case 104:
YY_RULE_SETUP
#line 245 "/home/runner/work/lukeparser/lukeparser/src/luke/parser/compiled/tmp.l"
{ returntokenFromString(yytext,HYPERREF_LINK_CHAR); }
	YY_BREAK
case 105:
/* rule 105 can match eol */
YY_RULE_SETUP
#line 246 "/home/runner/work/lukeparser/lukeparser/src/luke/parser/compiled/tmp.l"
{ returntokenFromString(yytext,HYPERREF_LINK_CHAR); }
	YY_BREAK
case 106:
YY_RULE_SETUP
#line 247 "/home/runner/work/lukeparser/lukeparser/src/luke/parser/compiled/tmp.l"
{ returntokenFromString(yytext,HYPERREF_LINK_ALT_CHAR); }
	YY_BREAK
case 107:
/* rule 107 can match eol */
YY_RULE_SETUP
#line 248 "/home/runner/work/lukeparser/lukeparser/src/luke/parser/compiled/tmp.l"
{ returntokenFromString(yytext,HYPERREF_LINK_ALT_CHAR); }
	YY_BREAK
case 108:
/* rule 108 can match eol */
YY_RULE_SETUP
#line 249 "/home/runner/work/lukeparser/lukeparser/src/luke/parser/compiled/tmp.l"
{ STATE_POP(); returntoken(HYPERREF_LINK_ALT_END); }
	YY_BREAK
case 109:
/* rule 109 can match eol */
YY_RULE_SETUP
#line 251 "/home/runner/work/lukeparser/lukeparser/src/luke/parser/compiled/tmp.l"
{ returntokenFromString(yytext,HYPERREF_CODE_CHAR); }
	YY_BREAK
case 110:
/* rule 110 can match eol */
YY_RULE_SETUP
#line 252 "/home/runner/work/lukeparser/lukeparser/src/luke/parser/compiled/tmp.l"
{ STATE_POP(); returntoken(HYPERREF_CODE_END); }
	YY_BREAK
case 111:
YY_RULE_SETUP
#line 253 "/home/runner/work/lukeparser/lukeparser/src/luke/parser/compiled/tmp.l"
{ returntokenFromString(yytext,HYPERREF_CODE_CHAR); }
	YY_BREAK
case 112:
/* rule 112 can match eol */
*yy_cp = yyg->yy_hold_char; /* undo effects of setting up yytext */
YY_LINENO_REWIND_TO(yy_cp - 1);
yyg->yy_c_buf_p = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 257 "/home/runner/work/lukeparser/lukeparser/src/luke/parser/compiled/tmp.l"
{ returntoken(HRULE); }
	YY_BREAK
case 113:
/* rule 113 can match eol */
*yy_cp = yyg->yy_hold_char; /* undo effects of setting up yytext */
YY_LINENO_REWIND_TO(yy_cp - 1);
yyg->yy_c_buf_p = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 258 "/home/runner/work/lukeparser/lukeparser/src/luke/parser/compiled/tmp.l"
{ returntoken(HRULE); }
	YY_BREAK
case 114:
/* rule 114 can match eol */
*yy_cp = yyg->yy_hold_char; /* undo effects of setting up yytext */
YY_LINENO_REWIND_TO(yy_cp - 1);
yyg->yy_c_buf_p = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 259 "/home/runner/work/lukeparser/lukeparser/src/luke/parser/compiled/tmp.l"
{ returntoken(HRULE); }
	YY_BREAK
case 115:
/* rule 115 can match eol */
*yy_cp = yyg->yy_hold_char; /* undo effects of setting up yytext */
YY_LINENO_REWIND_TO(yy_cp - 1);
yyg->yy_c_buf_p = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 261 "/home/runner/work/lukeparser/lukeparser/src/luke/parser/compiled/tmp.l"
{ returntoken(HEADINGHASH_END); }
	YY_BREAK
case 116:
YY_RULE_SETUP
#line 262 "/home/runner/work/lukeparser/lukeparser/src/luke/parser/compiled/tmp.l"
{ STATE_PUSH(HEADINGHASH_STATE); returntoken(HEADINGHASH); }
	YY_BREAK
case 117:
/* rule 117 can match eol */
*yy_cp = yyg->yy_hold_char; /* undo effects of setting up yytext */
YY_LINENO_REWIND_TO(yy_bp + 1);
yyg->yy_c_buf_p = yy_cp = yy_bp + 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 263 "/home/runner/work/lukeparser/lukeparser/src/luke/parser/compiled/tmp.l"
{ STATE_POP(); returntoken(HEADINGHASH_END); }
	YY_BREAK
case 118:
YY_RULE_SETUP
#line 264 "/home/runner/work/lukeparser/lukeparser/src/luke/parser/compiled/tmp.l"
{ returntoken(HEADINGHASH); }
	YY_BREAK
case 119:
/* rule 119 can match eol */
*yy_cp = yyg->yy_hold_char; /* undo effects of setting up yytext */
YY_LINENO_REWIND_TO(yy_cp - 1);
yyg->yy_c_buf_p = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 265 "/home/runner/work/lukeparser/lukeparser/src/luke/parser/compiled/tmp.l"
{ returntoken(HEADING_ULINEDBL); }
	YY_BREAK
case 120:
/* rule 120 can match eol */
*yy_cp = yyg->yy_hold_char; /* undo effects of setting up yytext */
YY_LINENO_REWIND_TO(yy_cp - 1);
yyg->yy_c_buf_p = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 266 "/home/runner/work/lukeparser/lukeparser/src/luke/parser/compiled/tmp.l"
{ returntoken(HEADING_ULINESGL); }
	YY_BREAK
case 121:
YY_RULE_SETUP
#line 267 "/home/runner/work/lukeparser/lukeparser/src/luke/parser/compiled/tmp.l"
{ returntoken(ULIST_SYM); }
	YY_BREAK
case 122:
YY_RULE_SETUP
#line 268 "/home/runner/work/lukeparser/lukeparser/src/luke/parser/compiled/tmp.l"
{ returntoken(ULIST_SYM); }
	YY_BREAK
case 123:
YY_RULE_SETUP
#line 269 "/home/runner/work/lukeparser/lukeparser/src/luke/parser/compiled/tmp.l"
{ returntoken(ULIST_SYM); }
	YY_BREAK
case 124:
YY_RULE_SETUP
#line 270 "/home/runner/work/lukeparser/lukeparser/src/luke/parser/compiled/tmp.l"
{ returntoken(ULIST_SYM); }
	YY_BREAK
case 125:
YY_RULE_SETUP
#line 271 "/home/runner/work/lukeparser/lukeparser/src/luke/parser/compiled/tmp.l"
{ returntoken(OLIST_SYM); }
	YY_BREAK
case 126:
YY_RULE_SETUP
#line 272 "/home/runner/work/lukeparser/lukeparser/src/luke/parser/compiled/tmp.l"
{ returntoken(OLIST_SYM); }
	YY_BREAK
case 127:
YY_RULE_SETUP
#line 273 "/home/runner/work/lukeparser/lukeparser/src/luke/parser/compiled/tmp.l"
{ returntoken(QUOTE_SYM); }
	YY_BREAK
case 128:
YY_RULE_SETUP
#line 274 "/home/runner/work/lukeparser/lukeparser/src/luke/parser/compiled/tmp.l"
{ returntoken(INDENT_SYM); }
	YY_BREAK
case 129:
YY_RULE_SETUP
#line 276 "/home/runner/work/lukeparser/lukeparser/src/luke/parser/compiled/tmp.l"
{ ess_state_stack('s',STRONG_START,STRONG_END) }
	YY_BREAK
case 130:
YY_RULE_SETUP
#line 277 "/home/runner/work/lukeparser/lukeparser/src/luke/parser/compiled/tmp.l"
{ ess_state_stack('e',EMPH_START,EMPH_END) }
	YY_BREAK
case 131:
YY_RULE_SETUP
#line 278 "/home/runner/work/lukeparser/lukeparser/src/luke/parser/compiled/tmp.l"
{ ess_state_stack('b',BOLD_START,BOLD_END) }
	YY_BREAK
case 132:
YY_RULE_SETUP
#line 279 "/home/runner/work/lukeparser/lukeparser/src/luke/parser/compiled/tmp.l"
{ ess_state_stack('i',ITALIC_START,ITALIC_END) }
	YY_BREAK
case 133:
YY_RULE_SETUP
#line 280 "/home/runner/work/lukeparser/lukeparser/src/luke/parser/compiled/tmp.l"
{ ess_state_stack('-',STRIKE_START,STRIKE_END) }
	YY_BREAK
case 134:
/* rule 134 can match eol */
YY_RULE_SETUP
#line 282 "/home/runner/work/lukeparser/lukeparser/src/luke/parser/compiled/tmp.l"
{ returntoken(BR); }
	YY_BREAK
case 135:
YY_RULE_SETUP
#line 283 "/home/runner/work/lukeparser/lukeparser/src/luke/parser/compiled/tmp.l"
{ returntokenFromString(chr_space, CHAR); }
	YY_BREAK
case 136:
YY_RULE_SETUP
#line 284 "/home/runner/work/lukeparser/lukeparser/src/luke/parser/compiled/tmp.l"
{ returntokenFromString(yytext, CHAR); }
	YY_BREAK
case 137:
YY_RULE_SETUP
#line 285 "/home/runner/work/lukeparser/lukeparser/src/luke/parser/compiled/tmp.l"
{ returntokenFromString(yytext, CHAR); }
	YY_BREAK
case YY_STATE_EOF(INITIAL):
case YY_STATE_EOF(EMPH_STATE):
case YY_STATE_EOF(STRONG_STATE):
case YY_STATE_EOF(STRIKE_STATE):
case YY_STATE_EOF(ML_COMMENT):
case YY_STATE_EOF(COMMENT):
case YY_STATE_EOF(CODEBLOCK_STATE):
case YY_STATE_EOF(CODEBLOCK_STATE_VERBATIM):
case YY_STATE_EOF(CODEINLINE_STATE):
case YY_STATE_EOF(MATHINLINE_STATE):
case YY_STATE_EOF(ATTRIBUTE_STATE):
case YY_STATE_EOF(HYPERREF_LINK_STATE):
case YY_STATE_EOF(HYPERREF_DEFINITION):
case YY_STATE_EOF(HEADINGHASH_STATE):
case YY_STATE_EOF(HYPERREF_CODE_STATE):
case YY_STATE_EOF(HYPERREF_LINK_ALT_STATE):
#line 286 "/home/runner/work/lukeparser/lukeparser/src/luke/parser/compiled/tmp.l"
{
        while (ais_i!= -1) {
            int end_would_be_unexpected = 1;
            if (ais[ais_i] == ML_COMMENT || ais[ais_i] == COMMENT)
                end_would_be_unexpected = 0;
            STATE_POP();
            //printf("Current State -> index:%d state:%d\n",ais_i,ais[ais_i]);
            if (end_would_be_unexpected) {
                yyset_extra(1,yyscanner);
                reset_stacks();
                returntoken(UNEXPECTED_END);
            }
        }

        // reset stacks
        reset_stacks();

        yyterminate();
    }
	YY_BREAK
case 138:
YY_RULE_SETUP
#line 306 "/home/runner/work/lukeparser/lukeparser/src/luke/parser/compiled/tmp.l"
ECHO;
	YY_BREAK
#line 2508 "lex.yy.c"

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - yyg->yytext_ptr) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = yyg->yy_hold_char;
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			yyg->yy_n_chars = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( yyg->yy_c_buf_p <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			yyg->yy_c_buf_p = yyg->yytext_ptr + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state( yyscanner );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state , yyscanner);

			yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++yyg->yy_c_buf_p;
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = yyg->yy_last_accepting_cpos;
				yy_current_state = yyg->yy_last_accepting_state;
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer( yyscanner ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				yyg->yy_did_buffer_switch_on_eof = 0;

				if ( yywrap( yyscanner ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					yyg->yy_c_buf_p = yyg->yytext_ptr + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! yyg->yy_did_buffer_switch_on_eof )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				yyg->yy_c_buf_p =
					yyg->yytext_ptr + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state( yyscanner );

				yy_cp = yyg->yy_c_buf_p;
				yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				yyg->yy_c_buf_p =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars];

				yy_current_state = yy_get_previous_state( yyscanner );

				yy_cp = yyg->yy_c_buf_p;
				yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
	} /* end of user's declarations */
} /* end of yylex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	char *source = yyg->yytext_ptr;
	int number_to_move, i;
	int ret_val;

	if ( yyg->yy_c_buf_p > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( yyg->yy_c_buf_p - yyg->yytext_ptr - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) (yyg->yy_c_buf_p - yyg->yytext_ptr - 1);

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER_LVALUE;

			int yy_c_buf_p_offset =
				(int) (yyg->yy_c_buf_p - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				int new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					yyrealloc( (void *) b->yy_ch_buf,
							 (yy_size_t) (b->yy_buf_size + 2) , yyscanner );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = NULL;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			yyg->yy_c_buf_p = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			yyg->yy_n_chars, num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	if ( yyg->yy_n_chars == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			yyrestart( yyin  , yyscanner);
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if ((yyg->yy_n_chars + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		int new_size = yyg->yy_n_chars + number_to_move + (yyg->yy_n_chars >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) yyrealloc(
			(void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf, (yy_size_t) new_size , yyscanner );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
		/* "- 2" to take care of EOB's */
		YY_CURRENT_BUFFER_LVALUE->yy_buf_size = (int) (new_size - 2);
	}

	yyg->yy_n_chars += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars + 1] = YY_END_OF_BUFFER_CHAR;

	yyg->yytext_ptr = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (yyscan_t yyscanner)
{
	yy_state_type yy_current_state;
	char *yy_cp;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	yy_current_state = yyg->yy_start;
	yy_current_state += YY_AT_BOL();

	for ( yy_cp = yyg->yytext_ptr + YY_MORE_ADJ; yy_cp < yyg->yy_c_buf_p; ++yy_cp )
		{
		YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			yyg->yy_last_accepting_state = yy_current_state;
			yyg->yy_last_accepting_cpos = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 641 )
				yy_c = yy_meta[yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state , yyscan_t yyscanner)
{
	int yy_is_jam;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner; /* This var may be unused depending upon options. */
	char *yy_cp = yyg->yy_c_buf_p;

	YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		yyg->yy_last_accepting_state = yy_current_state;
		yyg->yy_last_accepting_cpos = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 641 )
			yy_c = yy_meta[yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
	yy_is_jam = (yy_current_state == 640);

	(void)yyg;
	return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_UNPUT

    static void yyunput (int c, char * yy_bp , yyscan_t yyscanner)
{
	char *yy_cp;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

    yy_cp = yyg->yy_c_buf_p;

	/* undo effects of setting up yytext */
	*yy_cp = yyg->yy_hold_char;

	if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
		{ /* need to shift things up to make room */
		/* +2 for EOB chars. */
		int number_to_move = yyg->yy_n_chars + 2;
		char *dest = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[
					YY_CURRENT_BUFFER_LVALUE->yy_buf_size + 2];
		char *source =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move];

		while ( source > YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			*--dest = *--source;

		yy_cp += (int) (dest - source);
		yy_bp += (int) (dest - source);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars =
			yyg->yy_n_chars = (int) YY_CURRENT_BUFFER_LVALUE->yy_buf_size;

		if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
			YY_FATAL_ERROR( "flex scanner push-back overflow" );
		}

	*--yy_cp = (char) c;

    if ( c == '\n' ){
        --yylineno;
    }

	yyg->yytext_ptr = yy_bp;
	yyg->yy_hold_char = *yy_cp;
	yyg->yy_c_buf_p = yy_cp;
}

#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (yyscan_t yyscanner)
#else
    static int input  (yyscan_t yyscanner)
#endif

{
	int c;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	*yyg->yy_c_buf_p = yyg->yy_hold_char;

	if ( *yyg->yy_c_buf_p == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( yyg->yy_c_buf_p < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] )
			/* This was really a NUL. */
			*yyg->yy_c_buf_p = '\0';

		else
			{ /* need more input */
			int offset = (int) (yyg->yy_c_buf_p - yyg->yytext_ptr);
			++yyg->yy_c_buf_p;

			switch ( yy_get_next_buffer( yyscanner ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					yyrestart( yyin , yyscanner);

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( yywrap( yyscanner ) )
						return 0;

					if ( ! yyg->yy_did_buffer_switch_on_eof )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput(yyscanner);
#else
					return input(yyscanner);
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					yyg->yy_c_buf_p = yyg->yytext_ptr + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) yyg->yy_c_buf_p;	/* cast for 8-bit char's */
	*yyg->yy_c_buf_p = '\0';	/* preserve yytext */
	yyg->yy_hold_char = *++yyg->yy_c_buf_p;

	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = (c == '\n');
	if ( YY_CURRENT_BUFFER_LVALUE->yy_at_bol )
		
    do{ yylineno++;
        yycolumn=0;
    }while(0)
;

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * @param yyscanner The scanner object.
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void yyrestart  (FILE * input_file , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if ( ! YY_CURRENT_BUFFER ){
        yyensure_buffer_stack (yyscanner);
		YY_CURRENT_BUFFER_LVALUE =
            yy_create_buffer( yyin, YY_BUF_SIZE , yyscanner);
	}

	yy_init_buffer( YY_CURRENT_BUFFER, input_file , yyscanner);
	yy_load_buffer_state( yyscanner );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * @param yyscanner The scanner object.
 */
    void yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	/* TODO. We should be able to replace this entire function body
	 * with
	 *		yypop_buffer_state();
	 *		yypush_buffer_state(new_buffer);
     */
	yyensure_buffer_stack (yyscanner);
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*yyg->yy_c_buf_p = yyg->yy_hold_char;
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = yyg->yy_c_buf_p;
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	yy_load_buffer_state( yyscanner );

	/* We don't actually know whether we did this switch during
	 * EOF (yywrap()) processing, but the only time this flag
	 * is looked at is after yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	yyg->yy_did_buffer_switch_on_eof = 1;
}

static void yy_load_buffer_state  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	yyg->yy_n_chars = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	yyg->yytext_ptr = yyg->yy_c_buf_p = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	yyg->yy_hold_char = *yyg->yy_c_buf_p;
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * @param yyscanner The scanner object.
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE yy_create_buffer  (FILE * file, int  size , yyscan_t yyscanner)
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state ) , yyscanner );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) yyalloc( (yy_size_t) (b->yy_buf_size + 2) , yyscanner );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	yy_init_buffer( b, file , yyscanner);

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with yy_create_buffer()
 * @param yyscanner The scanner object.
 */
    void yy_delete_buffer (YY_BUFFER_STATE  b , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		yyfree( (void *) b->yy_ch_buf , yyscanner );

	yyfree( (void *) b , yyscanner );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a yyrestart() or at EOF.
 */
    static void yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file , yyscan_t yyscanner)

{
	int oerrno = errno;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	yy_flush_buffer( b , yyscanner);

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then yy_init_buffer was _probably_
     * called from yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * @param yyscanner The scanner object.
 */
    void yy_flush_buffer (YY_BUFFER_STATE  b , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		yy_load_buffer_state( yyscanner );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  @param yyscanner The scanner object.
 */
void yypush_buffer_state (YY_BUFFER_STATE new_buffer , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if (new_buffer == NULL)
		return;

	yyensure_buffer_stack(yyscanner);

	/* This block is copied from yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*yyg->yy_c_buf_p = yyg->yy_hold_char;
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = yyg->yy_c_buf_p;
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		yyg->yy_buffer_stack_top++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from yy_switch_to_buffer. */
	yy_load_buffer_state( yyscanner );
	yyg->yy_did_buffer_switch_on_eof = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  @param yyscanner The scanner object.
 */
void yypop_buffer_state (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if (!YY_CURRENT_BUFFER)
		return;

	yy_delete_buffer(YY_CURRENT_BUFFER , yyscanner);
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if (yyg->yy_buffer_stack_top > 0)
		--yyg->yy_buffer_stack_top;

	if (YY_CURRENT_BUFFER) {
		yy_load_buffer_state( yyscanner );
		yyg->yy_did_buffer_switch_on_eof = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void yyensure_buffer_stack (yyscan_t yyscanner)
{
	yy_size_t num_to_alloc;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if (!yyg->yy_buffer_stack) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
      num_to_alloc = 1; /* After all that talk, this was set to 1 anyways... */
		yyg->yy_buffer_stack = (struct yy_buffer_state**)yyalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								, yyscanner);
		if ( ! yyg->yy_buffer_stack )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		memset(yyg->yy_buffer_stack, 0, num_to_alloc * sizeof(struct yy_buffer_state*));

		yyg->yy_buffer_stack_max = num_to_alloc;
		yyg->yy_buffer_stack_top = 0;
		return;
	}

	if (yyg->yy_buffer_stack_top >= (yyg->yy_buffer_stack_max) - 1){

		/* Increase the buffer to prepare for a possible push. */
		yy_size_t grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = yyg->yy_buffer_stack_max + grow_size;
		yyg->yy_buffer_stack = (struct yy_buffer_state**)yyrealloc
								(yyg->yy_buffer_stack,
								num_to_alloc * sizeof(struct yy_buffer_state*)
								, yyscanner);
		if ( ! yyg->yy_buffer_stack )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset(yyg->yy_buffer_stack + yyg->yy_buffer_stack_max, 0, grow_size * sizeof(struct yy_buffer_state*));
		yyg->yy_buffer_stack_max = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_buffer  (char * base, yy_size_t  size , yyscan_t yyscanner)
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return NULL;

	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state ) , yyscanner );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_buffer()" );

	b->yy_buf_size = (int) (size - 2);	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = NULL;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	yy_switch_to_buffer( b , yyscanner );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to yylex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       yy_scan_bytes() instead.
 */
YY_BUFFER_STATE yy_scan_string (const char * yystr , yyscan_t yyscanner)
{
    
	return yy_scan_bytes( yystr, (int) strlen(yystr) , yyscanner);
}

/** Setup the input buffer state to scan the given bytes. The next call to yylex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_bytes  (const char * yybytes, int  _yybytes_len , yyscan_t yyscanner)
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = (yy_size_t) (_yybytes_len + 2);
	buf = (char *) yyalloc( n , yyscanner );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = yy_scan_buffer( buf, n , yyscanner);
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in yy_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yynoreturn yy_fatal_error (const char* msg , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;
	fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = yyg->yy_hold_char; \
		yyg->yy_c_buf_p = yytext + yyless_macro_arg; \
		yyg->yy_hold_char = *yyg->yy_c_buf_p; \
		*yyg->yy_c_buf_p = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the user-defined data for this scanner.
 * @param yyscanner The scanner object.
 */
YY_EXTRA_TYPE yyget_extra  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyextra;
}

/** Get the current line number.
 * @param yyscanner The scanner object.
 */
int yyget_lineno  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        if (! YY_CURRENT_BUFFER)
            return 0;
    
    return yylineno;
}

/** Get the current column number.
 * @param yyscanner The scanner object.
 */
int yyget_column  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        if (! YY_CURRENT_BUFFER)
            return 0;
    
    return yycolumn;
}

/** Get the input stream.
 * @param yyscanner The scanner object.
 */
FILE *yyget_in  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyin;
}

/** Get the output stream.
 * @param yyscanner The scanner object.
 */
FILE *yyget_out  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyout;
}

/** Get the length of the current token.
 * @param yyscanner The scanner object.
 */
int yyget_leng  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyleng;
}

/** Get the current token.
 * @param yyscanner The scanner object.
 */

char *yyget_text  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yytext;
}

/** Set the user-defined data. This data is never touched by the scanner.
 * @param user_defined The data to be associated with this scanner.
 * @param yyscanner The scanner object.
 */
void yyset_extra (YY_EXTRA_TYPE  user_defined , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyextra = user_defined ;
}

/** Set the current line number.
 * @param _line_number line number
 * @param yyscanner The scanner object.
 */
void yyset_lineno (int  _line_number , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        /* lineno is only valid if an input buffer exists. */
        if (! YY_CURRENT_BUFFER )
           YY_FATAL_ERROR( "yyset_lineno called with no buffer" );
    
    yylineno = _line_number;
}

/** Set the current column.
 * @param _column_no column number
 * @param yyscanner The scanner object.
 */
void yyset_column (int  _column_no , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        /* column is only valid if an input buffer exists. */
        if (! YY_CURRENT_BUFFER )
           YY_FATAL_ERROR( "yyset_column called with no buffer" );
    
    yycolumn = _column_no;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param _in_str A readable stream.
 * @param yyscanner The scanner object.
 * @see yy_switch_to_buffer
 */
void yyset_in (FILE *  _in_str , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyin = _in_str ;
}

void yyset_out (FILE *  _out_str , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyout = _out_str ;
}

int yyget_debug  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yy_flex_debug;
}

void yyset_debug (int  _bdebug , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yy_flex_debug = _bdebug ;
}

/* Accessor methods for yylval and yylloc */

YYSTYPE * yyget_lval  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yylval;
}

void yyset_lval (YYSTYPE *  yylval_param , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yylval = yylval_param;
}

YYLTYPE *yyget_lloc  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yylloc;
}
    
void yyset_lloc (YYLTYPE *  yylloc_param , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yylloc = yylloc_param;
}
    
/* User-visible API */

/* yylex_init is special because it creates the scanner itself, so it is
 * the ONLY reentrant function that doesn't take the scanner as the last argument.
 * That's why we explicitly handle the declaration, instead of using our macros.
 */
int yylex_init(yyscan_t* ptr_yy_globals)
{
    if (ptr_yy_globals == NULL){
        errno = EINVAL;
        return 1;
    }

    *ptr_yy_globals = (yyscan_t) yyalloc ( sizeof( struct yyguts_t ), NULL );

    if (*ptr_yy_globals == NULL){
        errno = ENOMEM;
        return 1;
    }

    /* By setting to 0xAA, we expose bugs in yy_init_globals. Leave at 0x00 for releases. */
    memset(*ptr_yy_globals,0x00,sizeof(struct yyguts_t));

    return yy_init_globals ( *ptr_yy_globals );
}

/* yylex_init_extra has the same functionality as yylex_init, but follows the
 * convention of taking the scanner as the last argument. Note however, that
 * this is a *pointer* to a scanner, as it will be allocated by this call (and
 * is the reason, too, why this function also must handle its own declaration).
 * The user defined value in the first argument will be available to yyalloc in
 * the yyextra field.
 */
int yylex_init_extra( YY_EXTRA_TYPE yy_user_defined, yyscan_t* ptr_yy_globals )
{
    struct yyguts_t dummy_yyguts;

    yyset_extra (yy_user_defined, &dummy_yyguts);

    if (ptr_yy_globals == NULL){
        errno = EINVAL;
        return 1;
    }

    *ptr_yy_globals = (yyscan_t) yyalloc ( sizeof( struct yyguts_t ), &dummy_yyguts );

    if (*ptr_yy_globals == NULL){
        errno = ENOMEM;
        return 1;
    }

    /* By setting to 0xAA, we expose bugs in
    yy_init_globals. Leave at 0x00 for releases. */
    memset(*ptr_yy_globals,0x00,sizeof(struct yyguts_t));

    yyset_extra (yy_user_defined, *ptr_yy_globals);

    return yy_init_globals ( *ptr_yy_globals );
}

static int yy_init_globals (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from yylex_destroy(), so don't allocate here.
     */

    yyg->yy_buffer_stack = NULL;
    yyg->yy_buffer_stack_top = 0;
    yyg->yy_buffer_stack_max = 0;
    yyg->yy_c_buf_p = NULL;
    yyg->yy_init = 0;
    yyg->yy_start = 0;

    yyg->yy_start_stack_ptr = 0;
    yyg->yy_start_stack_depth = 0;
    yyg->yy_start_stack =  NULL;

/* Defined in main.c */
#ifdef YY_STDINIT
    yyin = stdin;
    yyout = stdout;
#else
    yyin = NULL;
    yyout = NULL;
#endif

    /* For future reference: Set errno on error, since we are called by
     * yylex_init()
     */
    return 0;
}

/* yylex_destroy is for both reentrant and non-reentrant scanners. */
int yylex_destroy  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		yy_delete_buffer( YY_CURRENT_BUFFER , yyscanner );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		yypop_buffer_state(yyscanner);
	}

	/* Destroy the stack itself. */
	yyfree(yyg->yy_buffer_stack , yyscanner);
	yyg->yy_buffer_stack = NULL;

    /* Destroy the start condition stack. */
        yyfree( yyg->yy_start_stack , yyscanner );
        yyg->yy_start_stack = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * yylex() is called, initialization will occur. */
    yy_init_globals( yyscanner);

    /* Destroy the main struct (reentrant only). */
    yyfree ( yyscanner , yyscanner );
    yyscanner = NULL;
    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, const char * s2, int n , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;

	int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (const char * s , yyscan_t yyscanner)
{
	int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *yyalloc (yy_size_t  size , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;
	return malloc(size);
}

void *yyrealloc  (void * ptr, yy_size_t  size , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;

	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return realloc(ptr, size);
}

void yyfree (void * ptr , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;
	free( (char *) ptr );	/* see yyrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 306 "/home/runner/work/lukeparser/lukeparser/src/luke/parser/compiled/tmp.l"


int yywrap(yyscan_t scanner) {
  /* we will just terminate when we reach the end of the input file */
  return 1;
}


